@@ -1,6 +1,9 @@
-/* dat.c
+/* $Id: dat.c,v 1.17 2005/08/07 19:12:20 rousseau Exp $ */
+
+/*******************************************************************************
+ * dat.c
  * A module of J-Pilot http://jpilot.org
- * 
+ *
  * Copyright (C) 2001-2002 by Judd Montgomery
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,13 +18,14 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
+
 /*
  * Thanks to nseessle@mail.hh.provi.de
  * http://ourworld.compuserve.com/homepages/nseessle/frames/pilot/dat_e.htm
  * http://www.geocities.com/Heartland/Acres/3216/todo_dat.htm
  * Scott Leighton helphand@pacbell.net
- * 
+ *
  * For their descriptions of the dat formats.
  */
 
@@ -148,7 +152,7 @@ static int get_categories(FILE *in, struct CategoryAppInfo *ai)
    return count;
 }
 
-int get_repeat(FILE *in, struct Appointment *a)
+int get_repeat(FILE *in, struct Appointment *appt)
 {
    time_t t;
    struct tm *now;
@@ -164,17 +168,17 @@ int get_repeat(FILE *in, struct Appointment *a)
    printf("  repeat entry follows:\n");
    printf("%d exceptions\n", s);
 #endif
-   if (a) {
-      a->exception=NULL;
-      memset(&(a->repeatEnd), 0, sizeof(a->repeatEnd));
+   if (appt) {
+      appt->exception=NULL;
+      memset(&(appt->repeatEnd), 0, sizeof(appt->repeatEnd));
    }
 
-   if (a) {
-      a->exceptions=s;
+   if (appt) {
+      appt->exceptions=s;
       if (s>0) {
-	 a->exception=malloc(sizeof(struct tm) * s);
-	 if (!(a->exceptions)) {
-	    jp_logf(JP_LOG_WARN, "get_repeat(): Out of Memory\n");
+	 appt->exception=malloc(sizeof(struct tm) * s);
+	 if (!(appt->exceptions)) {
+	    jp_logf(JP_LOG_WARN, "get_repeat(): %s\n", _("Out of memory"));
 	 }
       }
    }
@@ -183,10 +187,10 @@ int get_repeat(FILE *in, struct Appointment *a)
    for (i=0; i<s; i++) {
       fread(str_long, 4, 1, in);
       l = x86_long(str_long);
-      if (a) {
+      if (appt) {
 	 t = l;
 	 now = localtime(&t);
-	 memcpy(&(a->exception[i]), now, sizeof(struct tm));
+	 memcpy(&(appt->exception[i]), now, sizeof(struct tm));
       }
 #ifdef JPILOT_DEBUG
       printf("date_exception_entry: ");
@@ -201,10 +205,10 @@ int get_repeat(FILE *in, struct Appointment *a)
 #endif
 
    if (s==0x0000) {
-      if (a) {
-	 a->repeatType=repeatNone;
+      if (appt) {
+	 appt->repeatType=repeatNone;
       }
-      return 0;
+      return EXIT_SUCCESS;
    }
 
    if (s==0xFFFF) {
@@ -231,8 +235,8 @@ int get_repeat(FILE *in, struct Appointment *a)
 
    fread(str_long, 4, 1, in);
    repeat_type = x86_long(str_long);
-   if (a) {
-      a->repeatType=repeat_type;
+   if (appt) {
+      appt->repeatType=repeat_type;
    }
 #ifdef JPILOT_DEBUG
    printf("repeatType=%d ", repeat_type);
@@ -265,29 +269,29 @@ int get_repeat(FILE *in, struct Appointment *a)
 #ifdef JPILOT_DEBUG
    printf("Interval = %d\n", l);
 #endif
-   if (a) {
-      a->repeatFrequency=l;
+   if (appt) {
+      appt->repeatFrequency=l;
    }
 
    fread(str_long, 4, 1, in);
    l = x86_long(str_long);
-   if (a) {
+   if (appt) {
       t = l;
       now = localtime(&t);
-      memcpy(&(a->repeatEnd), now, sizeof(struct tm));
+      memcpy(&(appt->repeatEnd), now, sizeof(struct tm));
    }
    if (t==0x749e77bf) {
-      a->repeatForever=TRUE;
+      appt->repeatForever=TRUE;
    } else {
-      a->repeatForever=FALSE;
+      appt->repeatForever=FALSE;
    }
 #ifdef JPILOT_DEBUG
    printf("repeatEnd: 0x%x -> ", l); print_date(l);
 #endif
    fread(str_long, 4, 1, in);
    l = x86_long(str_long);
-   if (a) {
-      a->repeatWeekstart=l;
+   if (appt) {
+      appt->repeatWeekstart=l;
    }
 #ifdef JPILOT_DEBUG
    printf("First Day of Week = %d\n", l);
@@ -310,7 +314,7 @@ int get_repeat(FILE *in, struct Appointment *a)
 
       fread(str_long, 1, 1, in);
       for (i=0, bit=1; i<7; i++, bit=bit<<1) {
-	 a->repeatDays[i]=( str_long[0] & bit );
+	 appt->repeatDays[i]=( str_long[0] & bit );
       }
 #ifdef JPILOT_DEBUG
       printf("Days Mask = %x\n", str_long[0]);
@@ -357,7 +361,7 @@ int get_repeat(FILE *in, struct Appointment *a)
       break;
    }
 
-   return 0;
+   return EXIT_SUCCESS;
 }
 
 
@@ -373,7 +377,7 @@ static int print_date(int palm_date)
    strftime(text, sizeof(text), "%02m/%02d/%Y %02H:%02M:%02S", now);
    printf("%s\n", text);
 
-   return 0;
+   return EXIT_SUCCESS;
 }
 #endif
 
@@ -406,7 +410,7 @@ int print_field(struct field *f)
       break;
    }
 
-   return 0;
+   return EXIT_SUCCESS;
 }
 #endif
 
@@ -448,11 +452,11 @@ int get_field(FILE *in, struct field *f)
       /* get_repeat(in, NULL); */
       break;
     default:
-      jp_logf(JP_LOG_WARN, "get_field(): unknown type = %ld\n", type);
+      jp_logf(JP_LOG_WARN, "get_field(): %s %ld\n", _("unknown type ="), type);
       break;
    }
 
-   return 0;
+   return EXIT_SUCCESS;
 }
 
 int dat_check_if_dat_file(FILE *in)
@@ -481,7 +485,7 @@ int dat_check_if_dat_file(FILE *in)
        (version[1]==1) && (version[0]==0)) {
       return DAT_MEMO_FILE;
    }
-   return 0;
+   return EXIT_SUCCESS;
 }
 
 int dat_read_header(FILE *in,
@@ -529,9 +533,9 @@ int dat_read_header(FILE *in,
    fread(filler, 4, 1, in);
    *field_count=x86_long(filler);
    if (*field_count != expected_field_count) {
-      jp_logf(JP_LOG_WARN, "fields per row count != %d, unknown format\n",
+      jp_logf(JP_LOG_WARN, _("fields per row count != %d, unknown format\n"),
 		  expected_field_count);
-      return -1;
+      return EXIT_FAILURE;
    }
    /* Schema record ID position */
    fread(filler, 4, 1, in);
@@ -543,26 +547,26 @@ int dat_read_header(FILE *in,
    fread(filler, 2, 1, in);
    *field_count = x86_short(filler);
    if (*field_count != expected_field_count) {
-      jp_logf(JP_LOG_WARN, "field count != %d, unknown format\n",
+      jp_logf(JP_LOG_WARN, _("field count != %d, unknown format\n"),
 		  expected_field_count);
-      return -1;
+      return EXIT_FAILURE;
    }
 
    /* Schema fields */
    fread(filler, (*field_count)*2, 1, in);
    if (memcmp(filler, schema, (*field_count)*2)) {
-      jp_logf(JP_LOG_WARN, "unknown format, file has wrong schema\n");
-      jp_logf(JP_LOG_WARN, "File schema is:");
+      jp_logf(JP_LOG_WARN, _("Unknown format, file has wrong schema\n"));
+      jp_logf(JP_LOG_WARN, _("File schema is:"));
       for (i=0; i<(*field_count)*2; i++) {
 	 jp_logf(JP_LOG_WARN, " %02d", (char)filler[i]);
       }
       jp_logf(JP_LOG_WARN, "\n");
-      jp_logf(JP_LOG_WARN, "It should be:  ");
+      jp_logf(JP_LOG_WARN, _("It should be:  "));
       for (i=0; i<(*field_count)*2; i++) {
 	 jp_logf(JP_LOG_WARN, " %02d", (char)schema[i]);
       }
       jp_logf(JP_LOG_WARN, "\n");
-      return -1;
+      return EXIT_FAILURE;
    }
 
    /* Get record count */
@@ -573,7 +577,7 @@ int dat_read_header(FILE *in,
 #ifdef JPILOT_DEBUG
    printf("Record Count = %ld\n", *rec_count);
 #endif
-   return 0;
+   return EXIT_SUCCESS;
 }
 
 
@@ -632,7 +636,7 @@ int dat_get_appointments(FILE *in, AppointmentList **alist, struct CategoryAppIn
 
    jp_logf(JP_LOG_DEBUG, "dat_get_appointments\n");
 
-   if (!alist) return 0;
+   if (!alist) return EXIT_SUCCESS;
    *alist=NULL;
 
    ret = dat_read_header(in, 15, schema, ai,
@@ -648,13 +652,13 @@ int dat_get_appointments(FILE *in, AppointmentList **alist, struct CategoryAppIn
    for (i=0; i<rec_count; i++) {
       temp_alist = malloc(sizeof(AppointmentList));
       if (!temp_alist) {
-	 jp_logf(JP_LOG_WARN, "dat_get_appointments(): Out of memory\n");
+	 jp_logf(JP_LOG_WARN, "dat_get_appointments(): %s\n", _("Out of memory"));
 	 return i;
       }
 #ifdef JPILOT_DEBUG
       printf("----- record %d -----\n", i+1);
 #endif
-      memset(&(temp_alist->ma.a), 0, sizeof(temp_alist->ma.a));
+      memset(&(temp_alist->mappt.appt), 0, sizeof(temp_alist->mappt.appt));
       temp_alist->next=NULL;
       temp_alist->app_type=DATEBOOK;
 
@@ -667,10 +671,10 @@ int dat_get_appointments(FILE *in, AppointmentList **alist, struct CategoryAppIn
 	 printf("rec field %d %s: ", j, rec_fields[j]); print_field(&(fa[j]));
 #endif
 	 if (fa[j].type!=schema[j*2]) {
-	    jp_logf(JP_LOG_WARN, "%s:%d Record %d, field %d: Invalid type.  Expected %d, found %d\n", __FILE__, __LINE__, i+1, j+3, schema[j*2], fa[j].type);
+	    jp_logf(JP_LOG_WARN, _("%s:%d Record %d, field %d: Invalid type.  Expected %d, found %d\n"), __FILE__, __LINE__, i+1, j+3, schema[j*2], fa[j].type);
 	    jp_logf(JP_LOG_WARN, _("read of file terminated\n"));
 	    free(temp_alist);
-	    return 0;
+	    return EXIT_FAILURE;
 	 }
       }
       /* Get Fields */
@@ -685,58 +689,58 @@ int dat_get_appointments(FILE *in, AppointmentList **alist, struct CategoryAppIn
 	 }
 #endif
 	 if (fa[j].type!=schema[j*2+6]) {
-	    jp_logf(JP_LOG_WARN, "%s:%d Record %d, field %d: Invalid type.  Expected %d, found %d\n", __FILE__, __LINE__, i+1, j+3, schema[j*2+6], fa[j].type);
+	    jp_logf(JP_LOG_WARN, _("%s:%d Record %d, field %d: Invalid type.  Expected %d, found %d\n"), __FILE__, __LINE__, i+1, j+3, schema[j*2+6], fa[j].type);
 	    jp_logf(JP_LOG_WARN, _("read of file terminated\n"));
 	    free(temp_alist);
-	    return 0;
+	    return EXIT_FAILURE;
 	 }
 	 if (fa[j].type==DAT_TYPE_REPEAT) {
-	    get_repeat(in, &(temp_alist->ma.a));
+	    get_repeat(in, &(temp_alist->mappt.appt));
 	 }
       }
       /* Start Time */
       t = fa[0].date;
       now = localtime(&t);
-      memcpy(&(temp_alist->ma.a.begin), now, sizeof(struct tm));
+      memcpy(&(temp_alist->mappt.appt.begin), now, sizeof(struct tm));
       /* End Time */
       t = fa[1].i;
       now = localtime(&t);
-      memcpy(&(temp_alist->ma.a.end), now, sizeof(struct tm));
+      memcpy(&(temp_alist->mappt.appt.end), now, sizeof(struct tm));
       /* Description */
       if (fa[2].str) {
-	 temp_alist->ma.a.description=fa[2].str;
+	 temp_alist->mappt.appt.description=fa[2].str;
       } else {
-	 temp_alist->ma.a.description=strdup("");
+	 temp_alist->mappt.appt.description=strdup("");
       }
       /* Duration */
       /* what is duration? (repeatForever?) */
       /* Note */
       if (fa[4].str) {
-	 temp_alist->ma.a.note=fa[4].str;
+	 temp_alist->mappt.appt.note=fa[4].str;
       } else {
-	 temp_alist->ma.a.note=strdup("");
+	 temp_alist->mappt.appt.note=strdup("");
       }
       /* Untimed */
-      temp_alist->ma.a.event=fa[5].i;
+      temp_alist->mappt.appt.event=fa[5].i;
       /* Private */
-      temp_alist->ma.attrib = 0;
+      temp_alist->mappt.attrib = 0;
       if (fa[6].i) {
-	 temp_alist->ma.attrib |= DAT_STATUS_PRIVATE;
+	 temp_alist->mappt.attrib |= DAT_STATUS_PRIVATE;
       }
       /* Category */
-      temp_alist->ma.unique_id = fa[7].i;
-      if (temp_alist->ma.unique_id > 15) {
-	 temp_alist->ma.unique_id = 15;
+      temp_alist->mappt.unique_id = fa[7].i;
+      if (temp_alist->mappt.unique_id > 15) {
+	 temp_alist->mappt.unique_id = 15;
+      }
+      if (temp_alist->mappt.unique_id < 0) {
+	 temp_alist->mappt.unique_id = 0;
       }
-      if (temp_alist->ma.unique_id < 0) {
-	 temp_alist->ma.unique_id = 0;
-      }	 
       /* Alarm Set */
-      temp_alist->ma.a.alarm=fa[8].i;
+      temp_alist->mappt.appt.alarm=fa[8].i;
       /* Alarm Advance Units */
-      temp_alist->ma.a.advance=fa[9].i;
+      temp_alist->mappt.appt.advance=fa[9].i;
       /* Alarm Advance Type */
-      temp_alist->ma.a.advanceUnits=fa[10].i;
+      temp_alist->mappt.appt.advanceUnits=fa[10].i;
 
       /* Append onto the end of the list */
       if (last_alist) {
@@ -747,7 +751,7 @@ int dat_get_appointments(FILE *in, AppointmentList **alist, struct CategoryAppIn
 	 *alist=last_alist;
       }
    }
-   return 0;
+   return EXIT_SUCCESS;
 }
 
 int dat_get_addresses(FILE *in, AddressList **addrlist, struct CategoryAppInfo *ai)
@@ -834,7 +838,7 @@ int dat_get_addresses(FILE *in, AddressList **addrlist, struct CategoryAppInfo *
 
    jp_logf(JP_LOG_DEBUG, "dat_get_addresses\n");
 
-   if (!addrlist) return 0;
+   if (!addrlist) return EXIT_SUCCESS;
    *addrlist=NULL;
 
    ret = dat_read_header(in, 30, schema, ai,
@@ -850,7 +854,7 @@ int dat_get_addresses(FILE *in, AddressList **addrlist, struct CategoryAppInfo *
    for (i=0; i<rec_count; i++) {
       temp_addrlist = malloc(sizeof(AddressList));
       if (!temp_addrlist) {
-	 jp_logf(JP_LOG_WARN, "dat_get_addresses(): Out of memory\n");
+	 jp_logf(JP_LOG_WARN, "dat_get_addresses(): %s\n", _("Out of memory"));
 	 return i;
       }
       temp_addrlist->next=NULL;
@@ -867,10 +871,10 @@ int dat_get_addresses(FILE *in, AddressList **addrlist, struct CategoryAppInfo *
 	 printf("rec field %d %s: ", j, rec_fields[j]); print_field(&(fa[j]));
 #endif
 	 if (fa[j].type!=schema[j*2]) {
-	    jp_logf(JP_LOG_WARN, "%s:%d Record %d, field %d: Invalid type.  Expected %d, found %d\n", __FILE__, __LINE__, i+1, j+3, schema[j*2], fa[j].type);
+	    jp_logf(JP_LOG_WARN, _("%s:%d Record %d, field %d: Invalid type.  Expected %d, found %d\n"), __FILE__, __LINE__, i+1, j+3, schema[j*2], fa[j].type);
 	    jp_logf(JP_LOG_WARN, _("read of file terminated\n"));
 	    free(temp_addrlist);
-	    return 0;
+	    return EXIT_FAILURE;
 	 }
       }
       /* Get Fields */
@@ -880,42 +884,42 @@ int dat_get_addresses(FILE *in, AddressList **addrlist, struct CategoryAppInfo *
 	 printf("field %d %s: ", j, field_names[j]); print_field(&(fa[j]));
 #endif
 	 if (fa[j].type!=schema[j*2+6]) {
-	    jp_logf(JP_LOG_WARN, "%s:%d Record %d, field %d: Invalid type.  Expected %d, found %d\n", __FILE__, __LINE__, i+1, j+3, schema[j*2+6], fa[j].type);
+	    jp_logf(JP_LOG_WARN, _("%s:%d Record %d, field %d: Invalid type.  Expected %d, found %d\n"), __FILE__, __LINE__, i+1, j+3, schema[j*2+6], fa[j].type);
 	    jp_logf(JP_LOG_WARN, _("read of file terminated\n"));
 	    free(temp_addrlist);
-	    return 0;
+	    return EXIT_FAILURE;
 	 }
       }
       for (k=0; k<19; k++) {
-	 temp_addrlist->ma.a.entry[k]=fa[dat_order[k]].str;
+	 temp_addrlist->maddr.addr.entry[k]=fa[dat_order[k]].str;
       }
-      temp_addrlist->ma.a.phoneLabel[0] = fa[4].i;
-      temp_addrlist->ma.a.phoneLabel[1] = fa[6].i;
-      temp_addrlist->ma.a.phoneLabel[2] = fa[8].i;
-      temp_addrlist->ma.a.phoneLabel[3] = fa[10].i;
-      temp_addrlist->ma.a.phoneLabel[4] = fa[12].i;
+      temp_addrlist->maddr.addr.phoneLabel[0] = fa[4].i;
+      temp_addrlist->maddr.addr.phoneLabel[1] = fa[6].i;
+      temp_addrlist->maddr.addr.phoneLabel[2] = fa[8].i;
+      temp_addrlist->maddr.addr.phoneLabel[3] = fa[10].i;
+      temp_addrlist->maddr.addr.phoneLabel[4] = fa[12].i;
       /* Private */
-      temp_addrlist->ma.attrib = 0;
+      temp_addrlist->maddr.attrib = 0;
       if (fa[20].i) {
-	 temp_addrlist->ma.attrib |= DAT_STATUS_PRIVATE;
+	 temp_addrlist->maddr.attrib |= DAT_STATUS_PRIVATE;
       }
       /* Category */
-      temp_addrlist->ma.unique_id = fa[21].i;
-      if (temp_addrlist->ma.unique_id > 15) {
-	 temp_addrlist->ma.unique_id = 15;
+      temp_addrlist->maddr.unique_id = fa[21].i;
+      if (temp_addrlist->maddr.unique_id > 15) {
+	 temp_addrlist->maddr.unique_id = 15;
+      }
+      if (temp_addrlist->maddr.unique_id < 0) {
+	 temp_addrlist->maddr.unique_id = 0;
       }
-      if (temp_addrlist->ma.unique_id < 0) {
-	 temp_addrlist->ma.unique_id = 0;
-      }	 
       /* Show phone in list */
-      temp_addrlist->ma.a.showPhone = fa[26].i - 1;
+      temp_addrlist->maddr.addr.showPhone = fa[26].i - 1;
       for (k=0; k<19; k++) {
-	 if (temp_addrlist->ma.a.entry[k]==NULL) {
-	    temp_addrlist->ma.a.entry[k]=strdup("");
+	 if (temp_addrlist->maddr.addr.entry[k]==NULL) {
+	    temp_addrlist->maddr.addr.entry[k]=strdup("");
 	 }
       }
       /* Append onto the end of the list */
-      if (temp_addrlist) {
+      if (last_addrlist) {
 	 last_addrlist->next=temp_addrlist;
 	 last_addrlist=temp_addrlist;
       } else {
@@ -923,7 +927,7 @@ int dat_get_addresses(FILE *in, AddressList **addrlist, struct CategoryAppInfo *
 	 *addrlist=last_addrlist;
       }
    }
-   return 0;
+   return EXIT_SUCCESS;
 }
 
 int dat_get_todos(FILE *in, ToDoList **todolist, struct CategoryAppInfo *ai)
@@ -968,7 +972,7 @@ int dat_get_todos(FILE *in, ToDoList **todolist, struct CategoryAppInfo *ai)
 
    jp_logf(JP_LOG_DEBUG, "dat_get_todos\n");
 
-   if (!todolist) return 0;
+   if (!todolist) return EXIT_SUCCESS;
    *todolist=NULL;
 
    ret = dat_read_header(in, 10, schema, ai,
@@ -984,7 +988,7 @@ int dat_get_todos(FILE *in, ToDoList **todolist, struct CategoryAppInfo *ai)
    for (i=0; i<rec_count; i++) {
       temp_todolist = malloc(sizeof(ToDoList));
       if (!temp_todolist) {
-	 jp_logf(JP_LOG_WARN, "dat_get_todos(): Out of memory\n");
+	 jp_logf(JP_LOG_WARN, "dat_get_todos(): %s\n", _("Out of memory"));
 	 jp_logf(JP_LOG_WARN, _("read of file terminated\n"));
 	 free(temp_todolist);
 	 return i;
@@ -1003,10 +1007,10 @@ int dat_get_todos(FILE *in, ToDoList **todolist, struct CategoryAppInfo *ai)
 	 printf("rec field %d %s: ", j, rec_fields[j]); print_field(&(fa[j]));
 #endif
 	 if (fa[j].type!=schema[j*2]) {
-	    jp_logf(JP_LOG_WARN, "%s:%d Record %d, field %d: Invalid type.  Expected %d, found %d\n", __FILE__, __LINE__, i+1, j+3, schema[j*2], fa[j].type);
+	    jp_logf(JP_LOG_WARN, _("%s:%d Record %d, field %d: Invalid type.  Expected %d, found %d\n"), __FILE__, __LINE__, i+1, j+3, schema[j*2], fa[j].type);
 	    jp_logf(JP_LOG_WARN, _("read of file terminated\n"));
 	    free(temp_todolist);
-	    return 0;
+	    return EXIT_FAILURE;
 	 }
       }
       /* Get Fields */
@@ -1016,10 +1020,10 @@ int dat_get_todos(FILE *in, ToDoList **todolist, struct CategoryAppInfo *ai)
 	 printf("field %d %s: ", j, field_names[j]); print_field(&(fa[j]));
 #endif
 	 if (fa[j].type!=schema[j*2+6]) {
-	    jp_logf(JP_LOG_WARN, "%s:%d Record %d, field %d: Invalid type.  Expected %d, found %d\n", __FILE__, __LINE__, i+1, j+3, schema[j*2+6], fa[j].type);
+	    jp_logf(JP_LOG_WARN, _("%s:%d Record %d, field %d: Invalid type.  Expected %d, found %d\n"), __FILE__, __LINE__, i+1, j+3, schema[j*2+6], fa[j].type);
 	    jp_logf(JP_LOG_WARN, _("read of file terminated\n"));
 	    free(temp_todolist);
-	    return 0;
+	    return EXIT_FAILURE;
 	 }
       }
       /* Description */
@@ -1073,7 +1077,7 @@ int dat_get_todos(FILE *in, ToDoList **todolist, struct CategoryAppInfo *ai)
       }
    }
 
-   return 0;
+   return EXIT_SUCCESS;
 }
 
 int dat_get_memos(FILE *in, MemoList **memolist, struct CategoryAppInfo *ai)
@@ -1107,7 +1111,7 @@ int dat_get_memos(FILE *in, MemoList **memolist, struct CategoryAppInfo *ai)
 
    jp_logf(JP_LOG_DEBUG, "dat_get_memos\n");
 
-   if (!memolist) return 0;
+   if (!memolist) return EXIT_SUCCESS;
    *memolist=NULL;
 
    ret = dat_read_header(in, 6, schema, ai,
@@ -1123,7 +1127,7 @@ int dat_get_memos(FILE *in, MemoList **memolist, struct CategoryAppInfo *ai)
    for (i=0; i<rec_count; i++) {
       temp_memolist = malloc(sizeof(MemoList));
       if (!temp_memolist) {
-	 jp_logf(JP_LOG_WARN, "dat_get_memos(): Out of memory\n");
+	 jp_logf(JP_LOG_WARN, "dat_get_memos(): %s\n", _("Out of memory"));
 	 return i;
       }
       temp_memolist->next=NULL;
@@ -1140,10 +1144,10 @@ int dat_get_memos(FILE *in, MemoList **memolist, struct CategoryAppInfo *ai)
 	 printf("rec field %d %s: ", j, rec_fields[j]); print_field(&(fa[j]));
 #endif
 	 if (fa[j].type!=schema[j*2]) {
-	    jp_logf(JP_LOG_WARN, "%s:%d Record %d, field %d: Invalid type.  Expected %d, found %d\n", __FILE__, __LINE__, i+1, j+3, schema[j*2], fa[j].type);
+	    jp_logf(JP_LOG_WARN, _("%s:%d Record %d, field %d: Invalid type.  Expected %d, found %d\n"), __FILE__, __LINE__, i+1, j+3, schema[j*2], fa[j].type);
 	    jp_logf(JP_LOG_WARN, _("read of file terminated\n"));
 	    free(temp_memolist);
-	    return 0;
+	    return EXIT_FAILURE;
 	 }
       }
       /* Get Fields */
@@ -1153,10 +1157,10 @@ int dat_get_memos(FILE *in, MemoList **memolist, struct CategoryAppInfo *ai)
 	 printf("field %d %s: ", j, field_names[j]); print_field(&(fa[j]));
 #endif
 	 if (fa[j].type!=schema[j*2+6]) {
-	    jp_logf(JP_LOG_WARN, "%s:%d Record %d, field %d: Invalid type.  Expected %d, found %d\n", __FILE__, __LINE__, i+1, j+3, schema[j*2+6], fa[j].type);
+	    jp_logf(JP_LOG_WARN, _("%s:%d Record %d, field %d: Invalid type.  Expected %d, found %d\n"), __FILE__, __LINE__, i+1, j+3, schema[j*2+6], fa[j].type);
 	    jp_logf(JP_LOG_WARN, _("read of file terminated\n"));
 	    free(temp_memolist);
-	    return 0;
+	    return EXIT_FAILURE;
 	 }
       }
       /* Memo */
@@ -1185,5 +1189,5 @@ int dat_get_memos(FILE *in, MemoList **memolist, struct CategoryAppInfo *ai)
       }
    }
 
-   return 0;
+   return EXIT_SUCCESS;
 }
