@@ -1,4 +1,7 @@
-/* install_gui.c
+/* $Id: install_gui.c,v 1.23 2005/12/18 14:54:39 rousseau Exp $ */
+
+/*******************************************************************************
+ * install_gui.c
  * A module of J-Pilot http://jpilot.org
  *
  * Copyright (C) 1999-2002 by Judd Montgomery
@@ -15,7 +18,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
+
 #include "config.h"
 #include "i18n.h"
 #include <gtk/gtk.h>
@@ -48,14 +52,14 @@ int install_remove_line(int deleted_line)
    in = jp_open_home_file(EPN"_to_install", "r");
    if (!in) {
       jp_logf(JP_LOG_DEBUG, "failed opening install_file\n");
-      return -1;
+      return EXIT_FAILURE;
    }
 
    out = jp_open_home_file(EPN"_to_install.tmp", "w");
    if (!out) {
       fclose(in);
       jp_logf(JP_LOG_DEBUG, "failed opening install_file.tmp\n");
-      return -1;
+      return EXIT_FAILURE;
    }
 
    for (line_count=0; (!feof(in)); line_count++) {
@@ -77,7 +81,7 @@ int install_remove_line(int deleted_line)
 
    rename_file(EPN"_to_install.tmp", EPN"_to_install");
 
-   return 0;
+   return EXIT_SUCCESS;
 }
 
 int install_append_line(const char *line)
@@ -87,17 +91,17 @@ int install_append_line(const char *line)
 
    out = jp_open_home_file(EPN"_to_install", "a");
    if (!out) {
-      return -1;
+      return EXIT_FAILURE;
    }
 
    r = fprintf(out, "%s\n", line);
    if (r==EOF) {
       fclose(out);
-      return -1;
+      return EXIT_FAILURE;
    }
    fclose(out);
 
-   return 0;
+   return EXIT_SUCCESS;
 }
 
 
@@ -123,8 +127,7 @@ static void
    jp_logf(JP_LOG_DEBUG, "Quit\n");
 
    sel = gtk_file_selection_get_filename(GTK_FILE_SELECTION(data));
-   strncpy(dir, sel, MAX_PREF_VALUE);
-   dir[MAX_PREF_VALUE]='\0';
+   g_strlcpy(dir, sel, sizeof(dir));
    i=strlen(dir)-1;
    if (i<0) i=0;
    if (dir[i]!='/') {
@@ -198,7 +201,7 @@ static int
 
    in = jp_open_home_file(EPN"_to_install", "r");
    if (!in) {
-      return -1;
+      return EXIT_FAILURE;
    }
 
    gtk_clist_freeze(GTK_CLIST(clist));
@@ -218,11 +221,11 @@ static int
    if (kept_line_selected > count -1) {
       kept_line_selected = count - 1;
    }
-   gtk_clist_select_row(GTK_CLIST(clist), kept_line_selected, 0);
+   clist_select_row(GTK_CLIST(clist), kept_line_selected, 0);
    fclose(in);
    gtk_clist_thaw(GTK_CLIST(clist));
 
-   return 0;
+   return EXIT_SUCCESS;
 }
 
 static void cb_clist_selection(GtkWidget      *clist,
@@ -243,11 +246,10 @@ int install_gui(GtkWidget *main_window, int w, int h, int x, int y)
    GtkWidget *label;
    char temp[256];
    const char *svalue;
-   gchar *titles[] = {"Files to be installed"
-   };
+   gchar *titles[2];
 
    if (filew) {
-      return 0;
+      return EXIT_SUCCESS;
    }
 
    line_selected = -1;
@@ -277,15 +279,15 @@ int install_gui(GtkWidget *main_window, int w, int h, int x, int y)
 
    /*Even though I hide the ok button I still want to connect its signal */
    /*because a double click on the file name also calls this callback */
-   gtk_widget_hide(GTK_WIDGET(GTK_FILE_SELECTION(filew)->ok_button));   
+   gtk_widget_hide(GTK_WIDGET(GTK_FILE_SELECTION(filew)->ok_button));
    gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(filew)->ok_button),
 		      "clicked", GTK_SIGNAL_FUNC(cb_add), filew);
 
-
-   strncpy(temp, _("Files to be installed"), sizeof(temp));
-   temp[sizeof(temp)-1]='\0';
-   titles[0]=temp;
+   /* i18n hack to have title correctly translated */
+   titles[0] = strdup(_("Files to be installed"));
+   titles[1]=NULL;
    clist = gtk_clist_new_with_titles(1, titles);
+   if (titles[0]) free(titles[0]);
    gtk_widget_set_usize(GTK_WIDGET(clist), 0, 166);
    gtk_clist_column_titles_passive(GTK_CLIST(clist));
    gtk_clist_set_selection_mode(GTK_CLIST(clist), GTK_SELECTION_BROWSE);
@@ -311,21 +313,33 @@ int install_gui(GtkWidget *main_window, int w, int h, int x, int y)
    gtk_widget_show(label);
 
 
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_ADD);
+#else
    button = gtk_button_new_with_label(_("Add"));
+#endif
    gtk_box_pack_start(GTK_BOX(GTK_FILE_SELECTION(filew)->ok_button->parent),
 		      button, TRUE, TRUE, 0);
    gtk_signal_connect(GTK_OBJECT(button),
 		      "clicked", GTK_SIGNAL_FUNC(cb_add), filew);
    gtk_widget_show(button);
 
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_REMOVE);
+#else
    button = gtk_button_new_with_label(_("Remove"));
+#endif
    gtk_box_pack_start(GTK_BOX(GTK_FILE_SELECTION(filew)->ok_button->parent),
 		      button, TRUE, TRUE, 0);
    gtk_signal_connect(GTK_OBJECT(button),
 		      "clicked", GTK_SIGNAL_FUNC(cb_remove), filew);
    gtk_widget_show(button);
 
-   button = gtk_button_new_with_label(_("Done"));
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
+#else
+   button = gtk_button_new_with_label(_("Close"));
+#endif
    gtk_box_pack_start(GTK_BOX(GTK_FILE_SELECTION(filew)->ok_button->parent),
 		      button, TRUE, TRUE, 0);
    gtk_signal_connect(GTK_OBJECT(button),
@@ -338,5 +352,5 @@ int install_gui(GtkWidget *main_window, int w, int h, int x, int y)
 
    gtk_main();
 
-   return 0;
+   return EXIT_SUCCESS;
 }
