@@ -1,6 +1,9 @@
-/* jpilot-sync.c
+/* $Id: jpilot-sync.c,v 1.26 2006/02/14 20:53:26 rikster5 Exp $ */
+
+/*******************************************************************************
+ * jpilot-sync.c
  * A module of J-Pilot http://jpilot.org
- * 
+ *
  * Copyright (C) 1999-2002 by Judd Montgomery
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,18 +18,25 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
 
 #include "config.h"
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
 #include <signal.h>
+#ifdef HAVE_LOCALE_H
+#include <locale.h>
+#endif
 #include "utils.h"
 #include "log.h"
 #include "prefs.h"
 #include "sync.h"
 #include "plugins.h"
+#include "i18n.h"
+#ifdef ENABLE_GTK2
+#include "otherconv.h"
+#endif
 
 /* this is a hack for now until I clean up the code */
 int *glob_date_label;
@@ -34,24 +44,34 @@ int pipe_to_parent, pipe_from_parent;
 pid_t glob_child_pid;
 GtkWidget *glob_dialog;
 pid_t glob_child_pid;
-
+GtkTooltips *glob_tooltips;
+int t_fmt_ampm;
 unsigned char skip_plugins;
 
+/* used only in GUI mode */
+pid_t jpilot_master_pid = -1;
+void output_to_pane(const char *str)
+{
+}
+
 /* hack */
 void cb_app_button(GtkWidget *widget, gpointer data)
 {
    return;
 }
 
-#define USAGE_STRING "\n"EPN"-sync [ -v || -h || [-d] [-P] [-b] [-l] [-p] port]\n"\
-" J-Pilot preferences are read to get port, rate, number of backups, etc.\n"\
-" -v = version\n"\
-" -h = help\n"\
-" -d = run in debug mode\n"\
-" -P = do not load plugins.\n"\
-" -b = Do a sync and then a backup, otherwise just do a sync.\n"\
-" -l = loop, otherwise sync once and exit.\n"\
-" -p {port} = Use this port to sync with instead of getting preferences.\n"\
+void fprint_jps_usage_string(FILE *out)
+{
+   fprintf(out, "%s-sync [ -v || -h || [-d] [-P] [-b] [-l] [-p] port]\n", EPN);
+   fprintf(out, "%s", _(" J-Pilot preferences are read to get port, rate, number of backups, etc.\n"));
+   fprintf(out, "%s", _(" -v = version\n"));
+   fprintf(out, "%s", _(" -h = help\n"));
+   fprintf(out, "%s", _(" -d = run in debug mode\n"));
+   fprintf(out, "%s", _(" -P = do not load plugins.\n"));
+   fprintf(out, "%s", _(" -b = Do a sync and then a backup, otherwise just do a sync.\n"));
+   fprintf(out, "%s", _(" -l = loop, otherwise sync once and exit.\n"));
+   fprintf(out, "%s", _(" -p {port} = Use this port to sync with instead of getting preferences.\n"));
+}
 
 static void sig_handler(int sig);
 
@@ -69,6 +89,17 @@ int main(int argc, char *argv[])
    jp_startup_info info;
 #endif
 
+   /* enable internationalization(i18n) before printing any output */
+#if defined(ENABLE_NLS)
+#  ifdef HAVE_LOCALE_H
+      char *current_locale;
+      current_locale = setlocale(LC_ALL, "");
+#  endif
+   bindtextdomain(EPN, LOCALEDIR);
+   textdomain(EPN);
+#endif
+
+
    done=cons_errors=0;
    port[0]='\0';
    glob_child_pid=0;
@@ -79,6 +110,12 @@ int main(int argc, char *argv[])
 
    pref_init();
    pref_read_rc_file();
+#ifdef ENABLE_GTK2
+   if (otherconv_init()) {
+      printf("Error: could not set encoding\n");
+      return EXIT_FAILURE;
+   }
+#endif
 
    pipe_from_parent=STDIN_FILENO;
    pipe_to_parent=STDOUT_FILENO;
@@ -94,7 +131,7 @@ int main(int argc, char *argv[])
       }
       if ( (!strncmp(argv[i], "-h", 2)) || (!strncasecmp(argv[1], "-?", 2))
 	  ) {
-	 printf("%s\n", USAGE_STRING);
+	 fprint_jps_usage_string(stderr);
 	 exit(0);
       }
       if (!strncasecmp(argv[i], "-d", 2)) {
@@ -116,8 +153,7 @@ int main(int argc, char *argv[])
       if (!strncmp(argv[i], "-p", 2)) {
 	 i++;
 	 if (i<argc) {
-	    strncpy(port, argv[i], MAX_PREF_VALUE);
-	    port[MAX_PREF_VALUE-1]='\0';
+	    g_strlcpy(port, argv[i], MAX_PREF_VALUE);
 	    /* Prefs are not saved, so this is not persistent */
 	    set_pref(PREF_PORT, 0, port, FALSE);
 	 }
@@ -211,7 +247,12 @@ int main(int argc, char *argv[])
       sleep(1);
    } while(loop);
 
-   return 0;
+#ifdef ENABLE_GTK2
+   otherconv_free();
+#endif
+
+   /* r is the return value of setup_sync(), 0 if OK */
+   return r;
 }
 
 static void sig_handler(int sig)
