@@ -1,4 +1,4 @@
-/* $Id: jpilot.c,v 1.140 2006/06/09 20:42:57 judd Exp $ */
+/* $Id: jpilot.c,v 1.143 2006/11/11 02:08:59 rikster5 Exp $ */
 
 /*******************************************************************************
  * jpilot.c
@@ -748,11 +748,11 @@ int bad_sync_exit_status(int exit_status)
    if ((exit_status == SYNC_ERROR_NOT_SAME_USERID) ||
        (exit_status == SYNC_ERROR_NOT_SAME_USER)) {
       return dialog_generic(GTK_WINDOW(window),
-			      _("Sync Problem"), DIALOG_WARNING, text1, 2, button_text);
+			      _("Sync Problem"), DIALOG_WARNING, _(text1), 2, button_text);
    }
    if (exit_status == SYNC_ERROR_NULL_USERID) {
       return dialog_generic(GTK_WINDOW(window),
-			    _("Sync Problem"), DIALOG_ERROR, text2, 1, button_text);
+			    _("Sync Problem"), DIALOG_ERROR, _(text2), 1, button_text);
    }
    return EXIT_FAILURE;
 }
@@ -761,13 +761,22 @@ void output_to_pane(const char *str)
 {
    int w, h, new_y;
    long ivalue;
+   GtkWidget *pane_hbox;
+   GtkRequisition size_requisition;
 
    /* Adjust window height to user preference or minimum size */
    get_pref(PREF_OUTPUT_HEIGHT, &ivalue, NULL);
    /* Make them look at something if output happens */
-   if (ivalue < 60) {
-      ivalue=60;
-      set_pref(PREF_OUTPUT_HEIGHT, 60, NULL, TRUE);
+   if (ivalue < 50) {
+#  ifdef ENABLE_GTK2
+      /* Ask GTK for size which is just large enough to show both buttons */
+      pane_hbox = gtk_paned_get_child2(GTK_PANED(output_pane));
+      gtk_widget_size_request(pane_hbox, &size_requisition);
+      ivalue = size_requisition.height + 1;
+#  else
+      ivalue = 50;
+#  endif
+      set_pref(PREF_OUTPUT_HEIGHT, ivalue, NULL, TRUE);
    }
    gdk_window_get_size(window->window, &w, &h);
    new_y = h - ivalue;
@@ -1953,10 +1962,20 @@ int main(int argc, char *argv[])
    GtkWidget *menubar;
 #ifdef ENABLE_GTK2
    GtkWidget *scrolled_window;
-   char *week_start;
-   int   pref_fdow = 0;
 #else
    GtkWidget *vscrollbar;
+#endif
+/* Extract first day of week preference from locale in GTK2 */
+#ifdef ENABLE_GTK2
+   int   pref_fdow = 0;
+#  ifdef HAVE__NL_TIME_FIRST_WEEKDAY
+      char *langinfo;
+      int week_1stday = 0;
+      int first_weekday = 1;
+      unsigned int week_origin;
+#  else
+      char *week_start;
+#  endif
 #endif
    unsigned char skip_past_alarms;
    unsigned char skip_all_alarms;
@@ -2179,18 +2198,31 @@ char * xpm_backup[] = {
    pref_read_rc_file();
 
    /* Extract first day of week preference from locale in GTK2 */
+
 #  ifdef ENABLE_GTK2
-#     ifdef HAVE_LANGINFO_H
+#     ifdef HAVE__NL_TIME_FIRST_WEEKDAY
 	 /* GTK 2.8 libraries */
-	 week_start = nl_langinfo (_NL_TIME_FIRST_WEEKDAY);
-	 pref_fdow = *((unsigned char *) week_start) - 1;
+         langinfo = nl_langinfo(_NL_TIME_FIRST_WEEKDAY);
+         first_weekday = langinfo[0];
+         langinfo = nl_langinfo(_NL_TIME_WEEK_1STDAY);
+         week_origin = GPOINTER_TO_INT(langinfo);
+         if (week_origin == 19971130)      /* Sunday */
+            week_1stday = 0;
+         else if (week_origin == 19971201) /* Monday */
+            week_1stday = 1;
+         else
+            g_warning ("Unknown value of _NL_TIME_WEEK_1STDAY.\n");
+
+         pref_fdow = (week_1stday + first_weekday - 1) % 7;
 #     else
 	 /* GTK 2.6 libraries */
 #        if defined(ENABLE_NLS)
 	    week_start = dgettext("gtk20", "calendar:week_start:0");
 	    if (strncmp("calendar:week_start:", week_start, 20) == 0) {
 	       pref_fdow = *(week_start + 20) - '0';
-	    }
+	    } else {
+               pref_fdow = -1;
+            }
 #        endif
 #     endif
       if (pref_fdow > 1)
@@ -2505,9 +2537,8 @@ char * xpm_backup[] = {
 
    /* Make the output text window */
    temp_hbox = gtk_hbox_new(FALSE, 0);
-   gtk_widget_set_usize(GTK_WIDGET(temp_hbox), 1, 1);
    gtk_container_set_border_width(GTK_CONTAINER(temp_hbox), 5);
-   gtk_paned_pack2(GTK_PANED(output_pane), temp_hbox, FALSE, FALSE);
+   gtk_paned_pack2(GTK_PANED(output_pane), temp_hbox, TRUE, TRUE);
 
    temp_vbox = gtk_vbox_new(FALSE, 3);
    gtk_container_set_border_width(GTK_CONTAINER(temp_vbox), 6);
