@@ -1,4 +1,4 @@
-/* $Id: libplugin.c,v 1.24 2005/10/24 15:27:48 rikster5 Exp $ */
+/* $Id: libplugin.c,v 1.29 2006/07/30 13:57:00 rousseau Exp $ */
 
 /*******************************************************************************
  * libplugin.c
@@ -367,11 +367,13 @@ int jp_free_DB_records(GList **br_list)
 /* Exact value of "Jan 1, 1970 0:00:00 GMT" - "Jan 1, 1904 0:00:00 GMT" */
 #define PILOT_TIME_DELTA (unsigned)(2082844800)
 
+#if 0
 static time_t
 pilot_time_to_unix_time (unsigned long raw_time)
 {
    return (time_t)(raw_time - PILOT_TIME_DELTA);
 }
+#endif
 
 /*
 static unsigned long
@@ -381,6 +383,7 @@ unix_time_to_pilot_time (time_t t)
 }
 */
 
+#if 0
 static unsigned int bytes_to_bin(unsigned char *bytes, unsigned int num_bytes)
 {
    unsigned int i, n;
@@ -390,42 +393,14 @@ static unsigned int bytes_to_bin(unsigned char *bytes, unsigned int num_bytes)
    }
    return n;
 }
-
-static int raw_header_to_header(RawDBHeader *rdbh, DBHeader *dbh)
-{
-   unsigned long temp;
-
-   strncpy(dbh->db_name, rdbh->db_name, 31);
-   dbh->db_name[31] = '\0';
-   dbh->flags = bytes_to_bin(rdbh->flags, 2);
-   dbh->version = bytes_to_bin(rdbh->version, 2);
-   temp = bytes_to_bin(rdbh->creation_time, 4);
-   dbh->creation_time = pilot_time_to_unix_time(temp);
-   temp = bytes_to_bin(rdbh->modification_time, 4);
-   dbh->modification_time = pilot_time_to_unix_time(temp);
-   temp = bytes_to_bin(rdbh->backup_time, 4);
-   dbh->backup_time = pilot_time_to_unix_time(temp);
-   dbh->modification_number = bytes_to_bin(rdbh->modification_number, 4);
-   dbh->app_info_offset = bytes_to_bin(rdbh->app_info_offset, 4);
-   dbh->sort_info_offset = bytes_to_bin(rdbh->sort_info_offset, 4);
-   strncpy(dbh->type, rdbh->type, 4);
-   dbh->type[4] = '\0';
-   strncpy(dbh->creator_id, rdbh->creator_id, 4);
-   dbh->creator_id[4] = '\0';
-   strncpy(dbh->unique_id_seed, rdbh->unique_id_seed, 4);
-   dbh->unique_id_seed[4] = '\0';
-   dbh->next_record_list_id = bytes_to_bin(rdbh->next_record_list_id, 4);
-   dbh->number_of_records = bytes_to_bin(rdbh->number_of_records, 2);
-
-   return EXIT_SUCCESS;
-}
+#endif
 
 int jp_get_app_info(char *DB_name, unsigned char **buf, int *buf_size)
 {
    FILE *in;
    int num;
    int rec_size;
-   RawDBHeader rdbh;
+   unsigned char raw_header[LEN_RAW_DB_HEADER];
    DBHeader dbh;
    char PDB_name[FILENAME_MAX];
 
@@ -441,7 +416,7 @@ int jp_get_app_info(char *DB_name, unsigned char **buf, int *buf_size)
       jp_logf(JP_LOG_WARN, _("%s:%d Error opening file: %s\n"), __FILE__, __LINE__, PDB_name);
       return EXIT_FAILURE;
    }
-   num = fread(&rdbh, sizeof(RawDBHeader), 1, in);
+   num = fread(raw_header, LEN_RAW_DB_HEADER, 1, in);
    if (num != 1) {
       if (ferror(in)) {
 	 jp_logf(JP_LOG_WARN, _("%s:%d Error reading file: %s\n"), __FILE__, __LINE__, PDB_name);
@@ -453,7 +428,7 @@ int jp_get_app_info(char *DB_name, unsigned char **buf, int *buf_size)
 	 return JPILOT_EOF;
       }
    }
-   raw_header_to_header(&rdbh, &dbh);
+   unpack_db_header(&dbh, raw_header);
 
    num = get_app_info_size(in, &rec_size);
    if (num) {
@@ -522,8 +497,7 @@ int jp_delete_record(char *DB_name, buf_rec *br, int flag)
 	 if (header.header_version==2) {
 	    /* Keep unique ID intact */
 	    if ((header.unique_id==br->unique_id) &&
-		((header.rt==NEW_PC_REC) || (header.rt==REPLACEMENT_PALM_REC))
-		) {
+	       ((header.rt==NEW_PC_REC) || (header.rt==REPLACEMENT_PALM_REC))) {
 	       if (fseek(pc_in, -header.header_len, SEEK_CUR)) {
 		  jp_logf(JP_LOG_WARN, "fseek failed\n");
 	       }
@@ -577,6 +551,110 @@ int jp_delete_record(char *DB_name, buf_rec *br, int flag)
    return EXIT_SUCCESS;
 }
 
+/*
+ * This undeletes a record from the appropriate Datafile
+ */
+int jp_undelete_record(char *DB_name, buf_rec *br, int flag)
+{
+   char filename[FILENAME_MAX];
+   char filename2[FILENAME_MAX];
+   FILE *pc_file  = NULL;
+   FILE *pc_file2 = NULL;
+   PC3RecordHeader header;
+   char *record;
+   unsigned int unique_id;
+   int found;
+   int ret = -1;
+   int num;
+
+   if (br==NULL) {
+      return EXIT_FAILURE;
+   }
+
+   unique_id = br->unique_id;
+   found  = FALSE;
+   record = NULL;
+
+   g_snprintf(filename, sizeof(filename), "%s.pc3", DB_name);
+   g_snprintf(filename2, sizeof(filename2), "%s.pct", filename);
+
+   pc_file = jp_open_home_file(filename , "r");
+   if (!pc_file) {
+      return EXIT_FAILURE;
+   }
+
+   pc_file2=jp_open_home_file(filename2, "w");
+   if (!pc_file2) {
+      fclose(pc_file);
+      return EXIT_FAILURE;
+   }
+
+   while(!feof(pc_file)) {
+      read_header(pc_file, &header);
+      if (feof(pc_file)) {
+	 break;
+      }
+      /* Skip copying DELETED_PALM_REC entry which undeletes it */
+      if (header.unique_id == unique_id &&
+	  header.rt == DELETED_PALM_REC) {
+	 found = TRUE;
+	 if (fseek(pc_file, header.rec_len, SEEK_CUR)) {
+	    jp_logf(JP_LOG_WARN, "fseek failed\n");
+	    ret = -1;
+	    break;
+	 }
+	 continue;
+      }
+      /* Change header on DELETED_PC_REC to undelete this type */
+      if (header.unique_id == unique_id &&
+          header.rt == DELETED_PC_REC) {
+	  found = TRUE;
+          header.rt = NEW_PC_REC;
+      }
+
+      /* Otherwise, keep whatever is there by copying it to the new pc3 file */
+      record = malloc(header.rec_len);
+      if (!record) {
+	 jp_logf(JP_LOG_WARN, "cleanup_pc_file(): Out of memory\n");
+	 ret = -1;
+	 break;
+      }
+      num = fread(record, header.rec_len, 1, pc_file);
+      if (num != 1) {
+	 if (ferror(pc_file)) {
+	    ret = -1;
+	    break;
+	 }
+      }
+      ret = write_header(pc_file2, &header);
+      ret = fwrite(record, header.rec_len, 1, pc_file2);
+      if (ret != 1) {
+	 ret = -1;
+	 break;
+      }
+      free(record);
+      record = NULL;
+   }
+
+   if (record) {
+      free(record);
+   }
+   if (pc_file) {
+      fclose(pc_file);
+   }
+   if (pc_file2) {
+      fclose(pc_file2);
+   }
+
+   if (found) {
+      rename_file(filename2, filename);
+   } else {
+      unlink_file(filename2);
+   }
+
+   return ret;
+}
+
 /*
  * if buf_rec->unique_id==0 then the palm assigns an ID, else
  *  use buf_rec->unique_id.
@@ -679,7 +757,7 @@ int jp_read_DB_files(char *DB_name, GList **records)
    unsigned int unique_id;
    mem_rec_header *mem_rh, *temp_mem_rh, *last_mem_rh;
    record_header rh;
-   RawDBHeader rdbh;
+   unsigned char raw_header[LEN_RAW_DB_HEADER];
    DBHeader dbh;
    buf_rec *temp_br;
    int temp_br_used;
@@ -700,7 +778,7 @@ int jp_read_DB_files(char *DB_name, GList **records)
       return -1;
    }
    /*Read the database header */
-   num = fread(&rdbh, sizeof(RawDBHeader), 1, in);
+   num = fread(raw_header, LEN_RAW_DB_HEADER, 1, in);
    if (num != 1) {
       if (ferror(in)) {
 	 jp_logf(JP_LOG_WARN, _("Error reading file: %s\n"), PDB_name);
@@ -711,7 +789,8 @@ int jp_read_DB_files(char *DB_name, GList **records)
 	 return JPILOT_EOF;
       }
    }
-   raw_header_to_header(&rdbh, &dbh);
+   unpack_db_header(&dbh, raw_header);
+
 #ifdef JPILOT_DEBUG
    jp_logf(JP_LOG_DEBUG, "db_name = %s\n", dbh.db_name);
    jp_logf(JP_LOG_DEBUG, "num records = %d\n", dbh.number_of_records);
@@ -748,7 +827,7 @@ int jp_read_DB_files(char *DB_name, GList **records)
       jp_logf(JP_LOG_DEBUG, "    unique_ID %d %d %d = ",rh.unique_ID[0],rh.unique_ID[1],rh.unique_ID[2]);
       jp_logf(JP_LOG_DEBUG, "%d\n",(rh.unique_ID[0]*256+rh.unique_ID[1])*256+rh.unique_ID[2]);
 #endif
-      temp_mem_rh = (mem_rec_header *)malloc(sizeof(mem_rec_header));
+      temp_mem_rh = malloc(sizeof(mem_rec_header));
       if (!temp_mem_rh) {
 	 jp_logf(JP_LOG_WARN, "jp_read_DB_files(): %s 1\n", _("Out of memory"));
 	 break;
@@ -925,4 +1004,3 @@ int jp_read_DB_files(char *DB_name, GList **records)
 
    return recs_returned;
 }
-
