@@ -1,4 +1,4 @@
-/* $Id: libplugin.h,v 1.20 2005/10/24 15:27:48 rikster5 Exp $ */
+/* $Id: libplugin.h,v 1.23 2006/07/05 00:34:11 judd Exp $ */
 
 /*******************************************************************************
  * libplugin.h
@@ -75,22 +75,7 @@ typedef struct mem_rec_header_s {
    struct mem_rec_header_s *next;
 } mem_rec_header;
 
-typedef struct {
-   unsigned char db_name[32];
-   unsigned char flags[2];
-   unsigned char version[2];
-   unsigned char creation_time[4];
-   unsigned char modification_time[4];
-   unsigned char backup_time[4];
-   unsigned char modification_number[4];
-   unsigned char app_info_offset[4];
-   unsigned char sort_info_offset[4];
-   unsigned char type[4];/*Database ID */
-   unsigned char creator_id[4];/*Application ID */
-   unsigned char unique_id_seed[4];
-   unsigned char next_record_list_id[4];
-   unsigned char number_of_records[2];
-} RawDBHeader;
+#define LEN_RAW_DB_HEADER 78
 
 typedef struct {
    char db_name[32];
@@ -263,6 +248,10 @@ int jp_read_DB_files(char *DB_name, GList **records);
  *This deletes a record from the appropriate Datafile
  */
 int jp_delete_record(char *DB_name, buf_rec *br, int flag);
+/*
+ *This undeletes a record from the appropriate Datafile
+ */
+int jp_undelete_record(char *DB_name, buf_rec *br, int flag);
 /*
  * Free the record list
  */
@@ -295,6 +284,18 @@ int get_app_info_size(FILE *in, int *size);
  */
 int dialog_save_changed_record(GtkWidget *widget, int changed);
 
+/* mon 0-11
+ * day 1-31
+ * year (year - 1900)
+ * This function will bring up the cal at mon, day, year
+ * After a new date is selected it will return mon, day, year
+ */
+int jp_cal_dialog(GtkWindow *main_window,
+		  const char *title, int monday_is_fdow,
+		  int *mon, int *day, int *year);
+
+int dialog_save_changed_record(GtkWidget *widget, int changed);
+
 /*
  * The preferences interface makes it easy to read and write name/value pairs
  * to a file.  Also access them efficiently.
