@@ -1,6 +1,9 @@
-/* log.c
+/* $Id: log.c,v 1.25 2005/01/21 08:56:49 rousseau Exp $ */
+
+/*******************************************************************************
+ * log.c
  * A module of J-Pilot http://jpilot.org
- * 
+ *
  * Copyright (C) 1999-2002 by Judd Montgomery
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,7 +18,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
 
 /*
  * Thanks to Jason Day for his patches that allowed plugins to log correctly
@@ -48,28 +51,8 @@ int glob_log_file_mask;
 int glob_log_stdout_mask;
 int glob_log_gui_mask;
 
-
-int jpilot_logf(int level, char *format, ...)
-{
-   va_list val;
-   int rval;
-   static int warned=0;
-
-   if (!((level & glob_log_file_mask) ||
-       (level & glob_log_stdout_mask) ||
-       (level & glob_log_gui_mask))) {
-      return 0;
-   }
-
-   if (!warned) {
-      fprintf(stderr, EPN": jpilot_logf deprecated, use jp_logf instead.\n");
-      warned=1;
-   }
-   va_start(val, format);
-   rval = jp_vlogf(level, format, val);
-   va_end(val);
-   return rval;
-}
+extern void output_to_pane(const char *str);
+extern pid_t jpilot_master_pid;
 
 int jp_logf(int level, char *format, ...)
 {
@@ -79,7 +62,7 @@ int jp_logf(int level, char *format, ...)
    if (!((level & glob_log_file_mask) ||
        (level & glob_log_stdout_mask) ||
        (level & glob_log_gui_mask))) {
-      return 0;
+      return EXIT_SUCCESS;
    }
 
    va_start(val, format);
@@ -91,7 +74,7 @@ int jp_logf(int level, char *format, ...)
 int jp_vlogf (int level, char *format, va_list val) {
 #define WRITE_MAX_BUF	4096
    char       		real_buf[WRITE_MAX_BUF+32];
-   char			*buf;
+   char			*buf, *local_buf;
    int			size;
    int			len;
    int			r;
@@ -102,21 +85,21 @@ int jp_vlogf (int level, char *format, va_list val) {
    if (!((level & glob_log_file_mask) ||
 	 (level & glob_log_stdout_mask) ||
 	 (level & glob_log_gui_mask))) {
-      return 0;
+      return EXIT_SUCCESS;
    }
 
    if ((!fp) && (err_count>10)) {
-      return -1;
+      return EXIT_FAILURE;
    }
    if ((!fp) && (err_count==10)) {
-      fprintf(stderr, _("Cannot open log file, giving up.\n"));
+      fprintf(stderr, _("Unable to open log file, giving up.\n"));
       err_count++;
-      return -1;
+      return EXIT_FAILURE;
    }
    if ((!fp) && (err_count<10)) {
       fp = jp_open_home_file(EPN".log", "w");
       if (!fp) {
-	 fprintf(stderr, _("Cannot open log file\n"));
+	 fprintf(stderr, _("Unable to open log file\n"));
 	 err_count++;
       }
    }
@@ -130,38 +113,57 @@ int jp_vlogf (int level, char *format, va_list val) {
    buf[WRITE_MAX_BUF-1] = '\0';
    size=strlen(buf);
 
+   local_buf = buf;
+#ifdef ENABLE_GTK2
+   /* UTF-8 text so transform in local encoding */
+   if (g_utf8_validate(buf, -1, NULL))
+   {
+      local_buf = g_locale_from_utf8(buf, -1, NULL, NULL, NULL);
+      if (NULL == local_buf)
+         local_buf = buf;
+   }
+#endif
+
    if ((fp) && (level & glob_log_file_mask)) {
-      fwrite(buf, size, 1, fp);
+      fwrite(local_buf, size, 1, fp);
       fflush(fp);
    }
 
    if (level & glob_log_stdout_mask) {
-      fputs(buf, stdout);
+      fputs(local_buf, stdout);
    }
 
+   /* free the buffer is a conversion was used */
+   if (local_buf != buf)
+       g_free(local_buf);
+
    if ((pipe_to_parent) && (level & glob_log_gui_mask)) {
-      sprintf(cmd, "%d:", PIPE_PRINT);
-      len = strlen(cmd);
-      buf = buf-len;
-      strncpy(buf, cmd, len);
-      size += len;
-      buf[size]='\0';
-      buf[size+1]='\n';
-      size += 2;
-      r = write(pipe_to_parent, buf, size);
-      if (r<0) fprintf(stderr, "write returned error %s %d\n", __FILE__, __LINE__);
-      fsync(pipe_to_parent);
+      /* do not use a pipe for intra-process log
+       * otherwise we may have a dead lock (jpilot freezes) */
+      if (getpid() == jpilot_master_pid)
+	 output_to_pane(buf);
+      else {
+	 sprintf(cmd, "%d:", PIPE_PRINT);
+	 len = strlen(cmd);
+	 buf = buf-len;
+	 strncpy(buf, cmd, len);
+	 size += len;
+	 buf[size]='\0';
+	 buf[size+1]='\n';
+	 size += 2;
+	 r = write(pipe_to_parent, buf, size);
+	 if (r<0)
+	    fprintf(stderr, "write returned error %s %d\n", __FILE__, __LINE__);
+      }
    }
 
-   return 0;
+   return EXIT_SUCCESS;
 }
 
 /*
  * This function writes data to the parent process.
  * A line feed, or a null must be the last character written.
  */
-extern int pipe_to_parent, pipe_from_parent;
-
 int write_to_parent(int command, char *format, ...)
 {
 #define WRITE_MAX_BUF 4096
