@@ -1,4 +1,7 @@
-/* log.h
+/* $Id: log.h,v 1.12 2005/10/24 15:27:48 rikster5 Exp $ */
+
+/*******************************************************************************
+ * log.h
  * A module of J-Pilot http://jpilot.org
  * 
  * Copyright (C) 1999-2002 by Judd Montgomery
@@ -15,13 +18,14 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
+
 #ifndef __LOG_H__
 #define __LOG_H__
 
 #include <stdarg.h>
 
-#define JP_LOG_DEBUG  1    /*debugging info for programers, and bug reports */
+#define JP_LOG_DEBUG  1    /*debugging info for programmers, and bug reports */
 #define JP_LOG_INFO   2    /*info, and misc messages */
 #define JP_LOG_WARN   4    /*worse messages */
 #define JP_LOG_FATAL  8    /*even worse messages */
