@@ -1,6 +1,9 @@
-/* memo.c
+/* $Id: memo.c,v 1.35 2005/09/26 03:27:59 judd Exp $ */
+
+/*******************************************************************************
+ * memo.c
  * A module of J-Pilot http://jpilot.org
- * 
+ *
  * Copyright (C) 1999-2002 by Judd Montgomery
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,7 +18,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
 
 #include "config.h"
 #include "i18n.h"
@@ -73,7 +76,7 @@ int memo_sort(MemoList **memol, int sort_order)
    int count, i;
 
    if (sort_order==SORT_DESCENDING) {
-      return 0;
+      return EXIT_SUCCESS;
    }
 
    /* Count the entries in the list */
@@ -83,14 +86,14 @@ int memo_sort(MemoList **memol, int sort_order)
 
    if (count<2) {
       /* We don't have to sort less than 2 items */
-      return 0;
+      return EXIT_SUCCESS;
    }
 
    /* Allocate an array to be qsorted */
    sort_memol = calloc(count, sizeof(MemoList *));
    if (!sort_memol) {
-      jp_logf(JP_LOG_WARN, "memo_sort(): Out of Memory\n");
-      return 0;
+      jp_logf(JP_LOG_WARN, "memo_sort(): %s\n", _("Out of memory"));
+      return EXIT_FAILURE;
    }
 
    /* Set our array to be a list of pointers to the nodes in the linked list */
@@ -122,12 +125,12 @@ int memo_sort(MemoList **memol, int sort_order)
 
    free(sort_memol);
 
-   return 0;
+   return EXIT_SUCCESS;
 }
 
 /*
  * This function writes to the MemoDB.pc3 file
- * 
+ *
  * memo - input - a memo to be written
  * rt - input - type of record to be written
  * attrib - input - attributes of record
@@ -137,8 +140,12 @@ int memo_sort(MemoList **memol, int sort_order)
 int pc_memo_write(struct Memo *memo, PCRecType rt, unsigned char attrib,
 		  unsigned int *unique_id)
 {
+#ifndef PILOT_LINK_0_12
    unsigned char record[65536];
    int rec_len;
+#else /* PILOT_LINK_0_12 */
+   pi_buffer_t *RecordBuffer;
+#endif /* PILOT_LINK_0_12 */
    buf_rec br;
    long ivalue;
    long char_set;
@@ -146,19 +153,34 @@ int pc_memo_write(struct Memo *memo, PCRecType rt, unsigned char attrib,
    get_pref(PREF_CHAR_SET, &char_set, NULL);
    if (char_set != CHAR_SET_LATIN1) {
       if (memo->text) {
-	 charset_j2p((unsigned char *)memo->text, strlen(memo->text)+1, char_set);
+	 charset_j2p(memo->text, strlen(memo->text)+1, char_set);
       }
    }
+#ifndef PILOT_LINK_0_12
    rec_len = pack_Memo(memo, record, 65535);
    if (!rec_len) {
       PRINT_FILE_LINE;
       jp_logf(JP_LOG_WARN, "pack_Memo %s\n", _("error"));
-      return -1;
+      return EXIT_FAILURE;
    }
+#else /* PILOT_LINK_0_12 */
+   RecordBuffer = pi_buffer_new(0);
+   if (pack_Memo(memo, RecordBuffer, memo_v1) == -1) {
+      PRINT_FILE_LINE;
+      jp_logf(JP_LOG_WARN, "pack_Memo %s\n", _("error"));
+      return EXIT_FAILURE;
+   }
+#endif /* PILOT_LINK_0_12 */
    br.rt=rt;
    br.attrib = attrib;
+#ifndef PILOT_LINK_0_12
    br.buf = record;
    br.size = rec_len;
+#else /* PILOT_LINK_0_12 */
+   br.buf = RecordBuffer->data;
+   br.size = RecordBuffer->used;
+
+#endif /* PILOT_LINK_0_12 */
    /* Keep unique ID intact */
    if (unique_id) {
       br.unique_id = *unique_id;
@@ -176,7 +198,11 @@ int pc_memo_write(struct Memo *memo, PCRecType rt, unsigned char attrib,
       *unique_id = br.unique_id;
    }
 
-   return 0;
+#ifdef PILOT_LINK_0_12
+   pi_buffer_free(RecordBuffer);
+#endif
+
+   return EXIT_SUCCESS;
 }
 
 void free_MemoList(MemoList **memo)
@@ -196,8 +222,6 @@ int get_memo_app_info(struct MemoAppInfo *ai)
    int num;
    unsigned int rec_size;
    unsigned char *buf;
-   long char_set;
-   int i;
    long ivalue;
    char DBname[32];
 
@@ -217,27 +241,18 @@ int get_memo_app_info(struct MemoAppInfo *ai)
       free(buf);
    }
    if ((num<0) || (rec_size<=0)) {
-      jp_logf(JP_LOG_WARN, _("Error reading %s\n"), DBname);
-      return -1;
+      jp_logf(JP_LOG_WARN, _("Error reading file: %s\n"), DBname);
+      return EXIT_FAILURE;
    }
 
-   get_pref(PREF_CHAR_SET, &char_set, NULL);
-   if (char_set != CHAR_SET_LATIN1) {
-      for (i = 0; i < 16; i++) {
-	 if (ai->category.name[i][0] != '\0') {
-	    charset_p2j((unsigned char *)ai->category.name[i], 16, char_set);
-	 }
-      }
-   }
-
-   return 0;
+   return EXIT_SUCCESS;
 }
 
 int get_memos(MemoList **memo_list, int sort_order)
 {
    return get_memos2(memo_list, sort_order, 1, 1, 1, CATEGORY_ALL);
 }
-/* 
+/*
  * sort_order: 0=descending, 1=ascending (memos are sorted if set in pdb file)
  * modified, deleted and private, 0 for no, 1 for yes, 2 for use prefs
  */
@@ -254,6 +269,9 @@ int get_memos2(MemoList **memo_list, int sort_order,
    long char_set;
    long ivalue;
    buf_rec *br;
+#ifdef PILOT_LINK_0_12
+   pi_buffer_t *RecordBuffer;
+#endif /* PILOT_LINK_0_12 */
 
    jp_logf(JP_LOG_DEBUG, "get_memos2()\n");
    if (modified==2) {
@@ -278,8 +296,12 @@ int get_memos2(MemoList **memo_list, int sort_order,
    get_pref(PREF_MEMO32_MODE, &ivalue, NULL);
    if (ivalue) {
       num = jp_read_DB_files("Memo32DB", &records);
+      if (-1 == num)
+        return 0;
    } else {
       num = jp_read_DB_files("MemoDB", &records);
+      if (-1 == num)
+        return 0;
    }
    /* Go to first entry in the list */
    for (temp_list = records; temp_list; temp_list = temp_list->prev) {
@@ -295,21 +317,36 @@ int get_memos2(MemoList **memo_list, int sort_order,
 	 continue;
       }
 
-      if ( ((br->rt==DELETED_PALM_REC) && (!keep_deleted)) ||
-	  ((br->rt==MODIFIED_PALM_REC) && (!keep_modified)) ) {
+      if ( ((br->rt==DELETED_PALM_REC)  && (!keep_deleted)) ||
+	   ((br->rt==DELETED_PC_REC)    && (!keep_deleted)) ||
+	   ((br->rt==MODIFIED_PALM_REC) && (!keep_modified)) ) {
 	 continue;
       }
-      if ((keep_priv != SHOW_PRIVATES) && 
+      if ((keep_priv != SHOW_PRIVATES) &&
 	  (br->attrib & dlpRecAttrSecret)) {
 	 continue;
       }
 
+#ifndef PILOT_LINK_0_12
       /* JPA unpacking sets memo buffer */
       num = unpack_Memo(&memo, br->buf, br->size);
+#else /* PILOT_LINK_0_12 */
+      RecordBuffer = pi_buffer_new(br->size);
+      memcpy(RecordBuffer->data, br->buf, br->size);
+      RecordBuffer->used = br->size;
+#endif /* PILOT_LINK_0_12 */
 
+#ifndef PILOT_LINK_0_12
       if (num <= 0) {
 	 continue;
       }
+#else /* PILOT_LINK_0_12 */
+      if (unpack_Memo(&memo, RecordBuffer, memo_v1) == -1) {
+	 pi_buffer_free(RecordBuffer);
+	 continue;
+      }
+      pi_buffer_free(RecordBuffer);
+#endif /* PILOT_LINK_0_12 */
 
       if ( ((br->attrib & 0x0F) != category) && category != CATEGORY_ALL) {
 	 continue;
@@ -318,16 +355,16 @@ int get_memos2(MemoList **memo_list, int sort_order,
       if (memo.text) {
 	 /* JPA character set conversion may require a longer buffer */
 
-         unsigned char *newtext; /* new buffer */
+         char *newtext; /* new buffer */
 
-         newtext = charset_p2newj((const unsigned char *)memo.text, strlen(memo.text)+1, char_set);
+         newtext = charset_p2newj(memo.text, strlen(memo.text)+1, char_set);
          free(memo.text);
-         memo.text = (char*)newtext;
+         memo.text = newtext;
       }
 
       temp_memo_list = malloc(sizeof(MemoList));
       if (!temp_memo_list) {
-	 jp_logf(JP_LOG_WARN, "get_memos2(): Out of memory\n");
+	 jp_logf(JP_LOG_WARN, "get_memos2(): %s\n", _("Out of memory"));
 	 break;
       }
       memcpy(&(temp_memo_list->mmemo.memo), &memo, sizeof(struct Memo));
