@@ -1,4 +1,4 @@
-/* $Id: monthview_gui.c,v 1.32 2005/01/29 12:09:01 rousseau Exp $ */
+/* $Id: monthview_gui.c,v 1.35 2006/06/23 13:38:22 rousseau Exp $ */
 
 /*******************************************************************************
  * monthview_gui.c
@@ -35,6 +35,7 @@
 #include "config.h"
 
 extern int datebook_category;
+extern int glob_app;
 
 static GtkWidget *window=NULL;
 static GtkWidget *glob_month_vbox;
@@ -164,6 +165,9 @@ static void cb_enter_selected_day(GtkWidget *widget,
 {
    int day = GPOINTER_TO_INT(data) + 1 - glob_offset;
 
+   if (glob_app != DATEBOOK)
+      return;
+
    /* Redisplay the day view based on the date the user clicked on */
    datebook_gui_setdate(glob_month_date.tm_year, glob_month_date.tm_mon, day);
 }
@@ -182,6 +186,9 @@ void hide_show_month_boxes()
    char str[40];
    int d;
    GtkWidget *text;
+#ifdef ENABLE_GTK2
+   char *markup_str;
+#endif
 
    /* Determine today for highlighting */
    now_today = get_highlighted_today(&glob_month_date);
@@ -206,9 +213,25 @@ void hide_show_month_boxes()
 #else
       text = glob_month_texts[n];
 #endif
-      g_snprintf(str, sizeof(str), "%d%s", d,
-		 d == now_today ? _(" (TODAY)") : "");
+      g_snprintf(str, sizeof(str), "%d", d);
+
+#ifdef ENABLE_GTK2
+      if (d == now_today)
+      {
+	 markup_str = g_markup_printf_escaped("<b>%s</b>", str);
+      } else {
+	 markup_str = g_markup_printf_escaped("%s", str);
+      }
+      gtk_label_set_markup(GTK_LABEL(glob_month_labels[n]), markup_str);
+      g_free(markup_str);
+#else
+      if (d == now_today)
+      {
+	 g_snprintf(str, sizeof(str), "%s%s", str, _(" (TODAY)"));
+      }
       gtk_label_set_text(GTK_LABEL(glob_month_labels[n]), str);
+#endif
+
       if (n<7) {
 	 if (d>0) {
 	    gtk_widget_show(GTK_WIDGET(text));
@@ -445,7 +468,9 @@ void monthview_gui(struct tm *date_in)
    struct tm date;
    GtkWidget *label;
    GtkWidget *button;
+#ifndef ENABLE_GTK2
    GtkWidget *arrow;
+#endif
    GtkWidget *align;
    GtkWidget *vbox;
    GtkWidget *hbox;
@@ -493,36 +518,54 @@ void monthview_gui(struct tm *date_in)
    align = gtk_alignment_new(0.5, 0.5, 0, 0);
    gtk_box_pack_start(GTK_BOX(vbox), align, FALSE, FALSE, 0);
 
-   hbox_temp = gtk_hbox_new(FALSE, 0);
+   hbox_temp = gtk_hbutton_box_new();
+   gtk_button_box_set_spacing(GTK_BUTTON_BOX(hbox_temp), 6);
+   gtk_container_set_border_width(GTK_CONTAINER(hbox_temp), 6);
 
    gtk_container_add(GTK_CONTAINER(align), hbox_temp);
 
    /*Make a left arrow for going back a week */
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_GO_BACK);
+#else
    button = gtk_button_new();
    arrow = gtk_arrow_new(GTK_ARROW_LEFT, GTK_SHADOW_OUT);
    gtk_container_add(GTK_CONTAINER(button), arrow);
+#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_month_move),
 		      GINT_TO_POINTER(-1));
    gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 3);
 
 
-   /* Create a "Quit" button */
+   /* Create a "Close" button */
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
+#else
    button = gtk_button_new_with_label(_("Close"));
+#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_quit), window);
    gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 0);
 
    /* Create a "Print" button */
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_PRINT);
+#else
    button = gtk_button_new_with_label(_("Print"));
+#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_month_print), window);
    gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 0);
 
    /*Make a right arrow for going forward a week */
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_GO_FORWARD);
+#else
    button = gtk_button_new();
    arrow = gtk_arrow_new(GTK_ARROW_RIGHT, GTK_SHADOW_OUT);
    gtk_container_add(GTK_CONTAINER(button), arrow);
+#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_month_move),
 		      GINT_TO_POINTER(1));
