@@ -1,4 +1,4 @@
-/* $Id: otherconv.c,v 1.25 2005/10/28 01:16:50 judd Exp $ */
+/* $Id: otherconv.c,v 1.1.1.10 2006-05-18 14:00:29 rousseau Exp $ */
 
 /*******************************************************************************
  * otherconv.c
@@ -112,6 +112,9 @@ char *char_set_to_text(int char_set)
       case CHAR_SET_1255_UTF:
 	 return "CP1255";
 
+      case CHAR_SET_949_UTF:
+	 return "CP949";
+
       case CHAR_SET_1252_UTF:
       default:
 	 return "CP1252";
@@ -256,7 +259,7 @@ void UTF_to_other(char *const buf, int buf_len)
       buf_out_ptr = malloc(buf_len);
       if (NULL == buf_out_ptr)
       {
-	 jp_logf(JP_LOG_WARN, errstr, inptr - buf);
+	 jp_logf(JP_LOG_WARN, "no more memory");
 	 return;
       }
       outptr = buf_out_ptr;
