@@ -1,4 +1,7 @@
-/* password.c
+/* $Id: password.c,v 1.24 2005/12/18 14:54:39 rousseau Exp $ */
+
+/*******************************************************************************
+ * password.c
  * A module of J-Pilot http://jpilot.org
  *
  * Copyright (C) 1999-2002 by Judd Montgomery
@@ -15,7 +18,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
+
 #include "config.h"
 #include <gtk/gtk.h>
 #include <stdio.h>
@@ -58,20 +62,20 @@ struct dialog_data {
 
 unsigned char short_salt[]=
 {
-   0x09, 0x02, 0x13, 0x45, 0x07, 0x04, 0x13, 0x44, 
-   0x0C, 0x08, 0x13, 0x5A, 0x32, 0x15, 0x13, 0x5D, 
-   0xD2, 0x17, 0xEA, 0xD3, 0xB5, 0xDF, 0x55, 0x63, 
+   0x09, 0x02, 0x13, 0x45, 0x07, 0x04, 0x13, 0x44,
+   0x0C, 0x08, 0x13, 0x5A, 0x32, 0x15, 0x13, 0x5D,
+   0xD2, 0x17, 0xEA, 0xD3, 0xB5, 0xDF, 0x55, 0x63,
    0x22, 0xE9, 0xA1, 0x4A, 0x99, 0x4B, 0x0F, 0x88
 };
 unsigned char long_salt[]=
 {
-   0xB1, 0x56, 0x35, 0x1A, 0x9C, 0x98, 0x80, 0x84, 
-   0x37, 0xA7, 0x3D, 0x61, 0x7F, 0x2E, 0xE8, 0x76, 
-   0x2A, 0xF2, 0xA5, 0x84, 0x07, 0xC7, 0xEC, 0x27, 
-   0x6F, 0x7D, 0x04, 0xCD, 0x52, 0x1E, 0xCD, 0x5B, 
-   0xB3, 0x29, 0x76, 0x66, 0xD9, 0x5E, 0x4B, 0xCA, 
-   0x63, 0x72, 0x6F, 0xD2, 0xFD, 0x25, 0xE6, 0x7B, 
-   0xC5, 0x66, 0xB3, 0xD3, 0x45, 0x9A, 0xAF, 0xDA, 
+   0xB1, 0x56, 0x35, 0x1A, 0x9C, 0x98, 0x80, 0x84,
+   0x37, 0xA7, 0x3D, 0x61, 0x7F, 0x2E, 0xE8, 0x76,
+   0x2A, 0xF2, 0xA5, 0x84, 0x07, 0xC7, 0xEC, 0x27,
+   0x6F, 0x7D, 0x04, 0xCD, 0x52, 0x1E, 0xCD, 0x5B,
+   0xB3, 0x29, 0x76, 0x66, 0xD9, 0x5E, 0x4B, 0xCA,
+   0x63, 0x72, 0x6F, 0xD2, 0xFD, 0x25, 0xE6, 0x7B,
+   0xC5, 0x66, 0xB3, 0xD3, 0x45, 0x9A, 0xAF, 0xDA,
    0x29, 0x86, 0x22, 0x6E, 0xB8, 0x03, 0x62, 0xBC
 };
 
@@ -87,7 +91,7 @@ void bin_to_hex_str(unsigned char *bin, char *hex_str, int len)
 
 /*
  * encoded is a pre-allocated buffer at least 34 bytes long
- * 
+ *
  * This is the hashing algorithm used in palm OS < 4.0.
  * It is not very secure and is reversible.
  */
@@ -120,8 +124,7 @@ void palm_encode_hash(unsigned char *ascii, unsigned char *encoded)
       return;
    }
 
-   strncpy(encoded, ascii, PASSWD_LEN);
-   encoded[PASSWD_LEN-1]='\0';
+   g_strlcpy(encoded, ascii, PASSWD_LEN);
    len = strlen((char *)encoded);
    for (ai=len; ai < PASSWD_LEN; ai++) {
       encoded[ai] = encoded[ai-len] + len;
@@ -140,13 +143,13 @@ void palm_encode_hash(unsigned char *ascii, unsigned char *encoded)
 	 m++;
 	 index++;
       }
-   }  
+   }
 }
 
 #ifdef USB_PILOT_LINK
 /*
  * encoded is a pre-allocated buffer at least 16 bytes long
- * 
+ *
  * This is the hashing algorithm used in palm OS >= 4.0.
  * Its just a plain ole' MD5.
  */
@@ -154,12 +157,12 @@ void palm_encode_md5(unsigned char *ascii, unsigned char *encoded)
 {
    struct MD5Context m;
    unsigned char digest[20];
-   
+
    MD5Init(&m);
    MD5Update(&m, ascii, strlen((char *)ascii));
    MD5Final(digest, &m);
-   
-   memcpy(encoded, digest, 16);   
+
+   memcpy(encoded, digest, 16);
 }
 #endif /* USB_PILOT_LINK */
 
@@ -173,7 +176,6 @@ int verify_password(char *password)
    unsigned char password_lower[PASSWD_LEN+2];
    const char *pref_password;
    char hex_str[68];
-   long ivalue;
 #endif
 
 #ifdef ENABLE_PRIVATE
@@ -190,7 +192,7 @@ int verify_password(char *password)
    /* Check to see that the password matches */
    palm_encode_hash(password_lower, encoded);
    bin_to_hex_str(encoded, hex_str, 32);
-   get_pref(PREF_PASSWORD, &ivalue, &pref_password);
+   get_pref(PREF_PASSWORD, NULL, &pref_password);
    if (!strcmp(hex_str, pref_password)) {
       return TRUE;
    }
@@ -204,7 +206,7 @@ int verify_password(char *password)
    palm_encode_md5((unsigned char *)password, encoded);
    bin_to_hex_str(encoded, hex_str, 32);
    hex_str[32]='\0';
-   get_pref(PREF_PASSWORD, &ivalue, &pref_password);
+   get_pref(PREF_PASSWORD, NULL, &pref_password);
    if (!strcmp(hex_str, pref_password)) {
       return TRUE;
    }
@@ -217,13 +219,9 @@ int verify_password(char *password)
 }
 
 /*
- * hide passed HIDE_PRIVATES will set the hide flag.
- * hide passed SHOW_PRIVATES will unset the hide flag and also need a
- *  correct password.
- * hide passed MASK_PRIVATES will unset the hide flag and also need a
- *  correct password if current state is not SHOW_PRIVATES.
+ * hide passed HIDE_PRIVATES, SHOW_PRIVATES or MASK_PRIVATES will set the flag.
  * hide passed GET_PRIVATES will return the current hide flag.
- * hide flag is always returned, it is boolean.
+ * hide flag is always returned.
  */
 int show_privates(int hide)
 {
@@ -232,23 +230,9 @@ int show_privates(int hide)
 #else
    static int hidden=SHOW_PRIVATES;
 #endif
-   
-   if (hide==GET_PRIVATES) {
-      return hidden;
-   }
-   if (hide==HIDE_PRIVATES) {
-      hidden=HIDE_PRIVATES;
-      return hidden;
-   }
-   if ((hide==MASK_PRIVATES) && (hidden==SHOW_PRIVATES)) {
-      hidden=MASK_PRIVATES;
-      return hidden;
-   }
-   if ( (hide==SHOW_PRIVATES) ||
-       ((hide==MASK_PRIVATES) && (hidden!=SHOW_PRIVATES)) ) {
 
-      hidden=SHOW_PRIVATES;
-   }
+   if (hide != GET_PRIVATES)
+      hidden = hide;
 
    return hidden;
 }
@@ -287,8 +271,7 @@ static gboolean cb_destroy_dialog(GtkWidget *widget)
    entry = gtk_entry_get_text(GTK_ENTRY(Pdata->entry));
 
    if (entry) {
-      strncpy(Pdata->text, entry, PASSWD_LEN);
-      Pdata->text[PASSWD_LEN]='\0';
+      g_strlcpy(Pdata->text, entry, PASSWD_LEN+1);
    }
 
    gtk_main_quit();
@@ -297,7 +280,7 @@ static gboolean cb_destroy_dialog(GtkWidget *widget)
 }
 
 /*
- * returns 1 if OK was pressed, 2 if cancel was hit
+ * returns 1 if cancel was pressed, 2 if OK was hit
  */
 int dialog_password(GtkWindow *main_window, char *ascii_password, int retry)
 {
@@ -309,10 +292,10 @@ int dialog_password(GtkWindow *main_window, char *ascii_password, int retry)
    int ret;
 
    if (!ascii_password) {
-      return -1;
+      return EXIT_FAILURE;
    }
    ascii_password[0]='\0';
-   ret = 2; 
+   ret = 2;
 
    dialog = gtk_widget_new(GTK_TYPE_WINDOW,
 			   "type", GTK_WINDOW_TOPLEVEL,
@@ -329,11 +312,17 @@ int dialog_password(GtkWindow *main_window, char *ascii_password, int retry)
 
    gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(main_window));
 
+   hbox1 = gtk_hbox_new(FALSE, 2);
+   gtk_container_add(GTK_CONTAINER(dialog), hbox1);
+#ifdef ENABLE_GTK2
+   gtk_box_pack_start(GTK_BOX(hbox1), gtk_image_new_from_stock(GTK_STOCK_DIALOG_AUTHENTICATION, GTK_ICON_SIZE_DIALOG), FALSE, FALSE, 2);
+#endif
+
    vbox1 = gtk_vbox_new(FALSE, 2);
 
    gtk_container_set_border_width(GTK_CONTAINER(vbox1), 5);
 
-   gtk_container_add(GTK_CONTAINER(dialog), vbox1);
+   gtk_container_add(GTK_CONTAINER(hbox1), vbox1);
 
    hbox1 = gtk_hbox_new(TRUE, 2);
    gtk_container_set_border_width(GTK_CONTAINER(hbox1), 5);
@@ -351,37 +340,48 @@ int dialog_password(GtkWindow *main_window, char *ascii_password, int retry)
    gtk_entry_set_visibility(GTK_ENTRY(entry), FALSE);
    gtk_signal_connect(GTK_OBJECT(entry), "activate",
 		      GTK_SIGNAL_FUNC(cb_dialog_button),
-		      GINT_TO_POINTER(DIALOG_SAID_1));
+		      GINT_TO_POINTER(DIALOG_SAID_2));
    gtk_box_pack_start(GTK_BOX(hbox1), entry, TRUE, TRUE, 1);
 
 
    /* Button Box */
-   hbox1 = gtk_hbox_new(TRUE, 2);
+   hbox1 = gtk_hbutton_box_new();
+   gtk_button_box_set_layout(GTK_BUTTON_BOX (hbox1), GTK_BUTTONBOX_END);
+   gtk_button_box_set_spacing(GTK_BUTTON_BOX(hbox1), 6);
    gtk_container_set_border_width(GTK_CONTAINER(hbox1), 5);
    gtk_box_pack_start(GTK_BOX(vbox1), hbox1, FALSE, FALSE, 2);
 
    /* Buttons */
-   button = gtk_button_new_with_label(_("OK"));
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
+#else
+   button = gtk_button_new_with_label(_("Cancel"));
+#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_dialog_button),
 		      GINT_TO_POINTER(DIALOG_SAID_1));
-   gtk_box_pack_start(GTK_BOX(hbox1), button, TRUE, TRUE, 1);
+   gtk_box_pack_start(GTK_BOX(hbox1), button, FALSE, FALSE, 1);
 
-   button = gtk_button_new_with_label(_("Cancel"));
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_OK);
+#else
+   button = gtk_button_new_with_label(_("OK"));
+#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_dialog_button),
 		      GINT_TO_POINTER(DIALOG_SAID_2));
-   gtk_box_pack_start(GTK_BOX(hbox1), button, TRUE, TRUE, 1);
-
+   gtk_box_pack_start(GTK_BOX(hbox1), button, FALSE, FALSE, 1);
+   GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
+   gtk_widget_grab_default(button);
 
    Pdata = malloc(sizeof(struct dialog_data));
    if (Pdata) {
       /* Set the default button pressed to CANCEL */
-      Pdata->button_hit = DIALOG_SAID_2;
+      Pdata->button_hit = DIALOG_SAID_1;
       Pdata->entry=entry;
       Pdata->text[0]='\0';
    }
-   gtk_object_set_data(GTK_OBJECT(dialog), "dialog_data", Pdata);                    
+   gtk_object_set_data(GTK_OBJECT(dialog), "dialog_data", Pdata);
 
    gtk_widget_grab_focus(GTK_WIDGET(entry));
 
@@ -395,7 +395,7 @@ int dialog_password(GtkWindow *main_window, char *ascii_password, int retry)
    if (Pdata->button_hit==DIALOG_SAID_2) {
       ret = 2;
    }
-   strncpy(ascii_password, Pdata->text, PASSWD_LEN);
+   g_strlcpy(ascii_password, Pdata->text, PASSWD_LEN+1);
 
    free(Pdata);
 
