@@ -1,4 +1,4 @@
-/* $Id: prefs.c,v 1.60 2005/10/07 19:30:59 rousseau Exp $ */
+/* $Id: prefs.c,v 1.65 2006/02/14 20:53:26 rikster5 Exp $ */
 
 /*******************************************************************************
  * prefs.c
@@ -34,6 +34,8 @@
 #include "otherconv.h"
 #endif
 
+extern int t_fmt_ampm;
+
 /*These are the default settings */
 /*name, usertype, filetype, ivalue, char *svalue, svalue_size; */
 static prefType glob_prefs[NUM_PREFS] = {
@@ -81,7 +83,7 @@ static prefType glob_prefs[NUM_PREFS] = {
      {"open_alarm_windows", INTTYPE, INTTYPE, 1, NULL, 0},
      {"do_alarm_command", INTTYPE, INTTYPE, 0, NULL, 0},
      {"alarm_command", CHARTYPE, CHARTYPE, 0, NULL, 0},
-     {"remind_in", CHARTYPE, CHARTYPE, 0, NULL, 0},
+     {"remind_in", INTTYPE, INTTYPE, 0, NULL, 0},
      {"remind_units", INTTYPE, INTTYPE, 0, NULL, 0},
    /* This is actually the password, but I wanted to name it something more discreet */
      {"session_id", CHARTYPE, CHARTYPE, 0, NULL, 0},
@@ -126,7 +128,7 @@ static prefType glob_prefs[NUM_PREFS] = {
      {"todo_days_till_due", INTTYPE, INTTYPE, 7, NULL, 0},
      {"show_tooltips", INTTYPE, INTTYPE, 1, NULL, 0},
      {"datebook_note_pane", INTTYPE, INTTYPE, 75, NULL, 0},
-     {"datebook_hi_today", INTTYPE, INTTYPE, 0, NULL, 0},
+     {"datebook_hi_today", INTTYPE, INTTYPE, 1, NULL, 0},
      {"datebook_anni_years", INTTYPE, INTTYPE, 0, NULL, 0},
      {"keyring_pane", INTTYPE, INTTYPE, 0, NULL, 0},
      {"expense_pane", INTTYPE, INTTYPE, 0, NULL, 0},
@@ -353,8 +355,7 @@ static int get_rcfile_name(int n, char *rc_copy)
    found = 0;
    for (i=0, temp_list=dir_list; temp_list; temp_list=temp_list->next, i++) {
       if (i == n) {
-	 strncpy(rc_copy, temp_list->name, MAX_PREF_VALUE);
-	 rc_copy[MAX_PREF_VALUE-1]='\0';
+	 g_strlcpy(rc_copy, temp_list->name, MAX_PREF_VALUE);
 	 found=1;
 	 break;
       }
@@ -371,6 +372,7 @@ static int get_rcfile_name(int n, char *rc_copy)
 #define NUM_SHORTDATES 7
 #define NUM_LONGDATES 6
 #define NUM_TIMES 10
+#define NUM_TIMES_NO_AMPM 6
 #define NUM_RATES 11
 #define NUM_PAPER_SIZES 2
 
@@ -409,6 +411,15 @@ int get_pref_possibility(int which, int n, char *pref_str)
       "%H,%M"
    };
 
+   const char *time_formats_no_ampm[] = {
+      "%H:%M:%S",
+      "%H.%M.%S",
+      "%H,%M,%S",
+      "%H:%M",
+      "%H.%M",
+      "%H,%M"
+   };
+
    static char *days[] = {
       N_("Sunday"),
       N_("Monday")
@@ -446,6 +457,7 @@ int get_pref_possibility(int which, int n, char *pref_str)
       "UTF: Japanese (SJIS)",
       "UTF: Hebrew (CP1255)",
       "UTF: Traditional Chinese (BIG-5)",
+      "UTF: Korean (CP949)",
    };
 
    static const char *paper_sizes[] = {
@@ -460,12 +472,20 @@ int get_pref_possibility(int which, int n, char *pref_str)
       break;
 
     case PREF_TIME:
-      if ((n >= NUM_TIMES) || (n<0)) {
-	 pref_str[0]='\0';
-	 return EXIT_FAILURE;
+      if (t_fmt_ampm) {
+	 if ((n >= NUM_TIMES) || (n<0)) {
+	    pref_str[0]='\0';
+	    return EXIT_FAILURE;
+	 }
+	 strcpy(pref_str, time_formats[n]);
+      } else {
+	 if ((n >= NUM_TIMES_NO_AMPM) || (n<0)) {
+	    pref_str[0]='\0';
+	    return EXIT_FAILURE;
+	 }
+	 strcpy(pref_str, time_formats_no_ampm[n]);
       }
-      strcpy(pref_str, time_formats[n]);
-      break;
+	 break;
 
     case PREF_SHORTDATE:
       if ((n >= NUM_SHORTDATES) || (n<0)) {
@@ -605,8 +625,7 @@ char *pref_lstrncpy_realloc(char **dest, const char *src, int *size, int max_siz
       }
       *size=new_size;
    }
-   strncpy(*dest, Psrc, new_size);
-   (*dest)[new_size-1]='\0';
+   g_strlcpy(*dest, Psrc, new_size);
 
    return *dest;
 }
@@ -696,8 +715,15 @@ static int validate_glob_prefs()
    int i, r;
    char svalue[MAX_PREF_VALUE];
 
-   if (glob_prefs[PREF_TIME].ivalue >= NUM_TIMES) {
-      glob_prefs[PREF_TIME].ivalue = NUM_TIMES - 1;
+   if (t_fmt_ampm) {
+      if (glob_prefs[PREF_TIME].ivalue >= NUM_TIMES) {
+	 glob_prefs[PREF_TIME].ivalue = NUM_TIMES - 1;
+      }
+   }
+   else {
+      if (glob_prefs[PREF_TIME].ivalue >= NUM_TIMES_NO_AMPM) {
+	 glob_prefs[PREF_TIME].ivalue = NUM_TIMES_NO_AMPM - 1;
+      }
    }
    if (glob_prefs[PREF_TIME].ivalue < 0) {
       glob_prefs[PREF_TIME].ivalue = 0;
