@@ -1,6 +1,9 @@
-/* restore_gui.c
+/* $Id: restore_gui.c,v 1.20 2006/05/18 16:31:13 rikster5 Exp $ */
+
+/*******************************************************************************
+ * restore_gui.c
  * A module of J-Pilot http://jpilot.org
- * 
+ *
  * Copyright (C) 2001-2002 by Judd Montgomery
  *
  * This program is free software; you can redistribute it and/or modify
@@ -15,7 +18,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
 
 #include "config.h"
 #include <gtk/gtk.h>
@@ -25,7 +28,7 @@
 #include <string.h>
 #include <sys/stat.h>
 #include <unistd.h>
-
+#include <stdlib.h>
 
 #include "utils.h"
 #include "prefs.h"
@@ -53,7 +56,7 @@ cb_restore_ok(GtkWidget *widget, gpointer data)
    char home_dir[FILENAME_MAX];
    struct stat buf, backup_buf;
    int r1, r2;
-   
+
    list=GTK_CLIST(restore_clist)->selection;
 
    get_home_file_name("", home_dir, sizeof(home_dir));
@@ -62,9 +65,9 @@ cb_restore_ok(GtkWidget *widget, gpointer data)
    g_snprintf(file, sizeof(file), "%s/"EPN"_to_install", home_dir);
    unlink(file);
 
-   jp_logf(JP_LOG_WARN, "-----===== Restore Handheld ======-----\n");
+   jp_logf(JP_LOG_WARN, "%s%s%s\n", "-----===== ", _("Restore Handheld"), " ======-----");
    for (temp_list=list; temp_list; temp_list = temp_list->next) {
-      gtk_clist_get_text(GTK_CLIST(restore_clist), (int)temp_list->data, 0, &text);
+      gtk_clist_get_text(GTK_CLIST(restore_clist), GPOINTER_TO_INT(temp_list->data), 0, &text);
       jp_logf(JP_LOG_DEBUG, "row %ld [%s]\n", (long) temp_list->data, text);
       /* Look for the file in the JPILOT_HOME and JPILOT_HOME/backup.
        * Restore the newest modified date one, or the only one.
@@ -92,7 +95,7 @@ cb_restore_ok(GtkWidget *widget, gpointer data)
 	 install_append_line(backup_file);
       }
    }
-   
+
    setup_sync(SYNC_NO_PLUGINS|SYNC_OVERRIDE_USER|SYNC_RESTORE);
 
    gtk_widget_destroy(data);
@@ -127,9 +130,9 @@ static int populate_clist_sub(char *path, int check_for_dups, int check_exts)
    } else {
       for (i=0; (dirent = readdir(dir)); i++) {
 	 if (i>1000) {
-	    jp_logf(JP_LOG_WARN, "populate_clist_sub(): infinite loop\n");
+	    jp_logf(JP_LOG_WARN, "populate_clist_sub(): %s\n", _("infinite loop"));
 	    closedir(dir);
-	    return -1;
+	    return EXIT_FAILURE;
 	 }
 	 if (dirent->d_name[0]=='.') {
 	    continue;
@@ -164,12 +167,24 @@ static int populate_clist_sub(char *path, int check_for_dups, int check_exts)
 	    if (found) continue;
 	 }
 	 row_text[0]=dirent->d_name;
+#ifdef ENABLE_GTK2
+	 {
+	    gchar *utf8_text;
+
+	    utf8_text = g_locale_to_utf8(row_text[0], -1, NULL, NULL, NULL);
+	    row_text[0] = utf8_text;
+	    gtk_clist_append(GTK_CLIST(restore_clist), row_text);
+	    g_free(utf8_text);
+	 }
+#else
 	 gtk_clist_append(GTK_CLIST(restore_clist), row_text);
+#endif
 	 num++;
       }
       closedir(dir);
    }
 
+   gtk_clist_sort (GTK_CLIST (restore_clist));
    return num;
 }
 
@@ -188,10 +203,10 @@ static int populate_clist()
    populate_clist_sub(path, 1, 1);
 
    for (i=0; i<GTK_CLIST(restore_clist)->rows; i++) {
-      gtk_clist_select_row(GTK_CLIST(restore_clist), i, 0);
+      clist_select_row(GTK_CLIST(restore_clist), i, 0);
    }
-   
-   return 0;
+
+   return EXIT_SUCCESS;
 }
 
 
@@ -205,7 +220,7 @@ int restore_gui(GtkWidget *main_window, int w, int h, int x, int y)
    GtkWidget *label;
    const char *svalue;
    long ivalue;
-   char str_int[10];
+   char str_int[20];
 
    jp_logf(JP_LOG_DEBUG, "restore_gui()\n");
 
@@ -232,19 +247,19 @@ int restore_gui(GtkWidget *main_window, int w, int h, int x, int y)
 
    /* Label for instructions */
    label = gtk_label_new(_("To restore your handheld:"));
-   gtk_misc_set_alignment(GTK_MISC(label), 0, 0);   
+   gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
    gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
    label = gtk_label_new(_("1. Choose all the applications you wish to restore.  The default is all."));
-   gtk_misc_set_alignment(GTK_MISC(label), 0, 0);   
+   gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
    gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
    label = gtk_label_new(_("2. Enter the User Name and User ID."));
-   gtk_misc_set_alignment(GTK_MISC(label), 0, 0);   
+   gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
    gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
    label = gtk_label_new(_("3. Press the OK button."));
-   gtk_misc_set_alignment(GTK_MISC(label), 0, 0);   
+   gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
    gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
    label = gtk_label_new(_("This will overwrite data that is currently on the handheld."));
-   gtk_misc_set_alignment(GTK_MISC(label), 0, 0);   
+   gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
    gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
 
    /* Put the memo list window up */
@@ -286,24 +301,35 @@ int restore_gui(GtkWidget *main_window, int w, int h, int x, int y)
    gtk_box_pack_start(GTK_BOX(hbox), user_id_entry, TRUE, TRUE, 0);
 
 
-   hbox = gtk_hbox_new(FALSE, 0);
+   hbox = gtk_hbutton_box_new();
+   gtk_container_set_border_width(GTK_CONTAINER(hbox), 12);
+   gtk_button_box_set_layout(GTK_BUTTON_BOX (hbox), GTK_BUTTONBOX_END);
+   gtk_button_box_set_spacing(GTK_BUTTON_BOX(hbox), 6);
    gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
-   button = gtk_button_new_with_label(_("OK"));
-   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
-   gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(cb_restore_ok), restore_window);
-
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
+#else
    button = gtk_button_new_with_label(_("Cancel"));
+#endif
    gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_restore_quit), restore_window);
 
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_OK);
+#else
+   button = gtk_button_new_with_label(_("OK"));
+#endif
+   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
+   gtk_signal_connect(GTK_OBJECT(button), "clicked",
+		      GTK_SIGNAL_FUNC(cb_restore_ok), restore_window);
+
    populate_clist();
 
    gtk_widget_show_all(restore_window);
 
    gtk_main();
 
-   return 0;
+   return EXIT_SUCCESS;
 }
