@@ -1,4 +1,4 @@
-/* $Id: search_gui.c,v 1.40 2006/01/10 06:25:00 rikster5 Exp $ */
+/* $Id: search_gui.c,v 1.42 2006/11/11 13:12:33 rousseau Exp $ */
 
 /*******************************************************************************
  * search_gui.c
@@ -53,6 +53,9 @@ static GtkAccelGroup *accel_group = NULL;
 
 static int clist_row_selected;
 
+static void cb_clist_selection(GtkWidget *clist, gint row, gint column,
+      GdkEventButton *event, gpointer data);
+
 int datebook_search_sort_compare(const void *v1, const void *v2)
 {
    AppointmentList **al1, **al2;
@@ -453,6 +456,9 @@ static void cb_entry(GtkWidget *widget, gpointer data)
     * This does NOT cause the main window to jump to the selected record. */
    clist_select_row(GTK_CLIST(clist), 0, 0);
 
+   /* select the first record found */
+   cb_clist_selection(clist, 0, 0, (GdkEventButton *)1, NULL);
+
    return;
 }
 
@@ -613,6 +619,10 @@ void cb_search_gui(GtkWidget *widget, gpointer data)
 		      GTK_SIGNAL_FUNC(cb_search), clist);
    gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
 
+   /* clicking on "Case Sensitive" also starts a search */
+   gtk_signal_connect(GTK_OBJECT(case_sense_checkbox), "clicked",
+		      GTK_SIGNAL_FUNC(cb_search), clist);
+
    /* Create a "Done" button */
 #ifdef ENABLE_GTK2
    button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
