@@ -1,4 +1,7 @@
-/* sync.h
+/* $Id: sync.h,v 1.13 2005/08/26 02:59:26 judd Exp $ */
+
+/*******************************************************************************
+ * sync.h
  * A module of J-Pilot http://jpilot.org
  * 
  * Copyright (C) 1999-2002 by Judd Montgomery
@@ -15,24 +18,27 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
+
 #ifndef _SYNC_H__
 #define _SYNC_H__
 
 #include <pi-dlp.h>
 
 /* Bitmasks for backup */
-#define SYNC_FULL_BACKUP   1
-#define SYNC_NO_PLUGINS    2
-#define SYNC_OVERRIDE_USER 4
-#define SYNC_NO_FORK       8
-#define SYNC_RESTORE       16
+#define SYNC_FULL_BACKUP   0x01
+#define SYNC_NO_PLUGINS    0x02
+#define SYNC_OVERRIDE_USER 0x04
+#define SYNC_NO_FORK       0x08
+#define SYNC_RESTORE       0x10
+#define SYNC_INSTALL_USER  0x20
 
 #define SYNC_ERROR_BIND            -10
 #define SYNC_ERROR_LISTEN          -11
 #define SYNC_ERROR_OPEN_CONDUIT    -12
 #define SYNC_ERROR_PI_ACCEPT       -13
 #define SYNC_ERROR_READSYSINFO     -14
+#define SYNC_ERROR_PI_CONNECT      -15
 #define SYNC_ERROR_NOT_SAME_USER   -20
 #define SYNC_ERROR_NOT_SAME_USERID -21
 #define SYNC_ERROR_NULL_USERID     -22
