@@ -1,4 +1,4 @@
-/* $Id: utils.c,v 1.95 2005/10/25 02:15:28 rikster5 Exp $ */
+/* $Id: utils.c,v 1.117 2006/07/30 14:01:00 rousseau Exp $ */
 
 /*******************************************************************************
  * utils.c
@@ -63,10 +63,6 @@ int dialog_result;
 
 unsigned int glob_find_id;
 
-/*Stuff for the calendar window */
-static int glob_cal_return_code;
-static int glob_cal_mon, glob_cal_day, glob_cal_year;
-
 /*
  * Returns usage string that needs to be freed by the caller
  */
@@ -89,24 +85,25 @@ void get_compile_options(char *string, int len)
 {
    g_snprintf(string, len,
 	      PN" version "VERSION"\n"
-	      " Copyright (C) 1999-2004 by Judd Montgomery\n"
-	      " judd@jpilot.org, http://jpilot.org\n"
+	      "  Copyright (C) 1999-2005 by Judd Montgomery\n"
+	      "  judd@jpilot.org, http://jpilot.org\n"
+	      "\n"
 	      PN" comes with ABSOLUTELY NO WARRANTY; for details see the file\n"
-	      "COPYING included with the source code, or in /usr/docs/jpilot/.\n\n"
+	      "COPYING included with the source code, or in /usr/share/docs/jpilot/.\n\n"
 	      "This program is free software; you can redistribute it and/or modify\n"
 	      "it under the terms of the GNU General Public License as published by\n"
 	      "the Free Software Foundation; version 2 of the License.\n\n"
 	      "%s %s %s\n"
 	      "%s\n"
-	      " %s - %s\n"
-	      " %s - %d.%d.%d\n"
-	      " %s - %s\n"
-	      " %s - %s\n"
-	      " %s - %s\n"
-	      " %s - %s\n"
-	      " %s - %s\n"
-	      " %s - %s\n"
-	      " %s - %s\n",
+	      "  %s - %s\n"
+	      "  %s - %d.%d.%d\n"
+	      "  %s - %s\n"
+	      "  %s - %s\n"
+	      "  %s - %s\n"
+	      "  %s - %s\n"
+	      "  %s - %s\n"
+	      "  %s - %s\n"
+	      "  %s - %s",
 	      _("Date compiled"), __DATE__, __TIME__,
 	      _("Compiled with these options:"),
 
@@ -174,6 +171,18 @@ int cat_compare(const void *v1, const void *v2)
    return strcmp((s1)->Pcat, (s2)->Pcat);
 }
 
+int get_timeout_interval()
+{
+   const char *svalue;
+
+   get_pref(PREF_TIME, NULL, &svalue);
+   if (strstr(svalue,"%S"))
+      return CLOCK_TICK;
+   else
+      return 60*CLOCK_TICK;
+
+}
+
 gint timeout_date(gpointer data)
 {
    extern GtkWidget *glob_date_label;
@@ -654,6 +663,7 @@ void set_bg_rgb_clist_row(GtkWidget *clist, int row, int r, int g, int b)
    color.red=r;
    color.green=g;
    color.blue=b;
+   color.pixel=0;
 
    new_style->base[GTK_STATE_NORMAL] = color;
    gtk_clist_set_row_style(GTK_CLIST(clist), row, new_style);
@@ -675,6 +685,8 @@ void set_fg_rgb_clist_cell(GtkWidget *clist, int row, int col, int r, int g, int
    fg_color.red=r;
    fg_color.green=g;
    fg_color.blue=b;
+   fg_color.pixel=0;
+
    new_style->fg[GTK_STATE_NORMAL]   = fg_color;
    new_style->fg[GTK_STATE_SELECTED] = fg_color;
    gtk_clist_set_cell_style(GTK_CLIST(clist), row, col, new_style);
@@ -978,13 +990,6 @@ int hack_clist_set_column_title_pixmap(GtkWidget *clist,
 /*
  * Start of GTK calendar code
  */
-#define PRESSED_P            100
-#define PRESSED_A            101
-#define PRESSED_TAB_OR_MINUS 102
-
-static GtkWidget *util_cal;
-static GtkWidget *cal_window;
-
 static void
 cb_today(GtkWidget *widget,
 	 gpointer   data)
@@ -1012,17 +1017,30 @@ cb_quit(GtkWidget *widget,
 	gpointer   data)
 {
    unsigned int y,m,d;
+   unsigned int *Py,*Pm,*Pd;
+   int *Preturn_code;
+   GtkWidget *cal=NULL;
+   GtkWidget *window;
 
-   glob_cal_return_code = GPOINTER_TO_INT(data);
+   window = gtk_widget_get_toplevel(widget);
 
-   if (glob_cal_return_code==CAL_DONE) {
-      gtk_calendar_get_date(GTK_CALENDAR(util_cal),&y,&m,&d);
-      glob_cal_mon=m;
-      glob_cal_day=d;
-      glob_cal_year=y;
+   Preturn_code = gtk_object_get_data(GTK_OBJECT(window), "return_code");
+   if (Preturn_code) *Preturn_code = GPOINTER_TO_INT(data);
+   cal = gtk_object_get_data(GTK_OBJECT(window), "cal");
+
+   if (*Preturn_code==CAL_DONE) {
+      if (cal) {
+	 gtk_calendar_get_date(GTK_CALENDAR(cal),&y,&m,&d);
+	 Pm = gtk_object_get_data(GTK_OBJECT(window), "mon");
+	 Pd = gtk_object_get_data(GTK_OBJECT(window), "day");
+	 Py = gtk_object_get_data(GTK_OBJECT(window), "year");
+	 if (Pm) *Pm=m;
+	 if (Pd) *Pd=d;
+	 if (Py) *Py=y;
+      }
    }
 
-   gtk_widget_destroy(cal_window);
+   gtk_widget_destroy(window);
 }
 
 /* mon 0-11
@@ -1038,75 +1056,99 @@ int cal_dialog(GtkWindow *main_window,
    GtkWidget *button;
    GtkWidget *vbox;
    GtkWidget *hbox;
-   glob_cal_mon = *mon;
-   glob_cal_day = *day;
-   glob_cal_year = (*year) + 1900;
+   GtkWidget *cal;
+   GtkWidget *window;
+   int return_code;
 
-   cal_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-   gtk_window_set_title(GTK_WINDOW(cal_window), title);
+   window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+   gtk_window_set_title(GTK_WINDOW(window), title);
 
-   gtk_window_set_position(GTK_WINDOW(cal_window), GTK_WIN_POS_MOUSE);
+   gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_MOUSE);
 
-   gtk_window_set_modal(GTK_WINDOW(cal_window), TRUE);
+   gtk_window_set_modal(GTK_WINDOW(window), TRUE);
 
-   gtk_window_set_transient_for(GTK_WINDOW(cal_window), GTK_WINDOW(main_window));
+   gtk_window_set_transient_for(GTK_WINDOW(window), GTK_WINDOW(main_window));
 
-   gtk_signal_connect(GTK_OBJECT(cal_window), "destroy",
-		      GTK_SIGNAL_FUNC(cb_destroy), cal_window);
+   gtk_signal_connect(GTK_OBJECT(window), "destroy",
+		      GTK_SIGNAL_FUNC(cb_destroy), window);
 
    vbox = gtk_vbox_new(FALSE, 0);
-   gtk_container_add(GTK_CONTAINER(cal_window), vbox);
+   gtk_container_add(GTK_CONTAINER(window), vbox);
 
-   util_cal = gtk_calendar_new();
-   gtk_box_pack_start(GTK_BOX(vbox), util_cal, TRUE, TRUE, 0);
+   cal = gtk_calendar_new();
+   gtk_box_pack_start(GTK_BOX(vbox), cal, TRUE, TRUE, 0);
 
-   hbox = gtk_hbox_new(FALSE, 0);
+   hbox = gtk_hbutton_box_new();
+   gtk_container_set_border_width(GTK_CONTAINER(hbox), 12);
+   gtk_button_box_set_layout(GTK_BUTTON_BOX (hbox), GTK_BUTTONBOX_END);
+   gtk_button_box_set_spacing(GTK_BUTTON_BOX(hbox), 6);
    gtk_container_add(GTK_CONTAINER(vbox), hbox);
 
-   gtk_calendar_display_options(GTK_CALENDAR(util_cal),
+   gtk_calendar_display_options(GTK_CALENDAR(cal),
 				GTK_CALENDAR_SHOW_HEADING |
 				GTK_CALENDAR_SHOW_DAY_NAMES |
 				/*GTK_CALENDAR_NO_MONTH_CHANGE |*/
 				GTK_CALENDAR_SHOW_WEEK_NUMBERS |
 				(monday_is_fdow ? GTK_CALENDAR_WEEK_START_MONDAY : 0));
 
-   /* gtk_signal_connect(GTK_OBJECT(util_cal), "day_selected", cb_cal_sel, NULL); */
-   gtk_signal_connect(GTK_OBJECT(util_cal), "day_selected_double_click", GTK_SIGNAL_FUNC(cb_quit),
+   /* gtk_signal_connect(GTK_OBJECT(cal), "day_selected", cb_cal_sel, NULL); */
+   gtk_signal_connect(GTK_OBJECT(cal), "day_selected_double_click", GTK_SIGNAL_FUNC(cb_quit),
 		      GINT_TO_POINTER(CAL_DONE));
 
-   /* gtk_calendar_mark_day(GTK_CALENDAR(util_cal), 23); */
+   /* gtk_calendar_mark_day(GTK_CALENDAR(cal), 23); */
 
-   gtk_calendar_select_month(GTK_CALENDAR(util_cal), *mon, (*year)+1900);
-   gtk_calendar_select_day(GTK_CALENDAR(util_cal), *day);
+   gtk_calendar_select_month(GTK_CALENDAR(cal), *mon, (*year)+1900);
+   gtk_calendar_select_day(GTK_CALENDAR(cal), *day);
 
 
    /* Bottom Buttons */
-   button = gtk_button_new_with_label(_("OK"));
-   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
-   gtk_signal_connect(GTK_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(cb_quit),
-		      GINT_TO_POINTER(CAL_DONE));
-
-   button = gtk_button_new_with_label(_("Today"));
-   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
-   gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(cb_today), util_cal);
-
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
+#else
    button = gtk_button_new_with_label(_("Cancel"));
+#endif
    gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
    gtk_signal_connect(GTK_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(cb_quit),
 		      GINT_TO_POINTER(CAL_CANCEL));
 
-   gtk_widget_show_all(cal_window);
+   button = gtk_button_new_with_label(_("Today"));
+   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
+   gtk_signal_connect(GTK_OBJECT(button), "clicked",
+		      GTK_SIGNAL_FUNC(cb_today), cal);
+
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_OK);
+#else
+   button = gtk_button_new_with_label(_("OK"));
+#endif
+   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
+   gtk_signal_connect(GTK_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(cb_quit),
+		      GINT_TO_POINTER(CAL_DONE));
+
+   gtk_object_set_data(GTK_OBJECT(window), "mon", mon);
+   gtk_object_set_data(GTK_OBJECT(window), "day", day);
+   gtk_object_set_data(GTK_OBJECT(window), "year", year);
+   gtk_object_set_data(GTK_OBJECT(window), "return_code", &return_code);
+   gtk_object_set_data(GTK_OBJECT(window), "cal", cal);
+   
+   gtk_widget_show_all(window);
 
    gtk_main();
 
-   if (glob_cal_return_code==CAL_DONE) {
-      *mon = glob_cal_mon;
-      *day = glob_cal_day;
-      *year = glob_cal_year - 1900;
+   if (return_code == CAL_DONE) {
+      *year -= 1900;
    }
 
-   return glob_cal_return_code;
+   return return_code;
+}
+
+int jp_cal_dialog(GtkWindow *main_window,
+		  const char *title, int monday_is_fdow,
+		  int *mon, int *day, int *year)
+{
+   return cal_dialog(main_window,
+		     title, monday_is_fdow,
+		     mon, day, year);
 }
 /*
  * End of GTK calendar code
@@ -1132,32 +1174,31 @@ static gboolean cb_destroy_dialog(GtkWidget *widget)
 }
 
 /* nob = number of buttons */
-int dialog_generic_with_text(GtkWindow *main_window,
-			     int w, int h,
-			     char *title, char *frame_text,
-			     char *text, int nob, char *button_text[],
-			     int with_text)
+int dialog_generic(GtkWindow *main_window,
+			     char *title, int type,
+			     char *text, int nob, char *button_text[])
 {
    GtkWidget *button, *label1;
+   GtkWidget *hbox1, *vbox1, *vbox2;
+   int i;
 #ifdef ENABLE_GTK2
-   GtkTextView *text_widget;
-#else
-   GtkText *text_widget;
+   GtkWidget *image;
+   char *markup;
 #endif
 
-   GtkWidget *hbox1, *vbox1;
-   GtkWidget *frame1;
-   int i;
+   /* This gdk function call is required in order to avoid a GTK
+    * error which causes X and the mouse pointer to lock up.
+    * The lockup is generated whenever a modal dialog is created
+    * from the callback routine of a clist. */
+   gdk_pointer_ungrab(GDK_CURRENT_TIME);
 
    dialog_result=0;
    glob_dialog = gtk_widget_new(GTK_TYPE_WINDOW,
 				"type", GTK_WINDOW_TOPLEVEL,
 				"window_position", GTK_WIN_POS_MOUSE,
-				"title", title,
 				NULL);
-   if (w && h) {
-      gtk_window_set_default_size(GTK_WINDOW(glob_dialog), w, h);
-   }
+
+   gtk_window_set_title(GTK_WINDOW(glob_dialog), title);
 
    gtk_signal_connect(GTK_OBJECT(glob_dialog), "destroy",
                       GTK_SIGNAL_FUNC(cb_destroy_dialog), glob_dialog);
@@ -1168,39 +1209,54 @@ int dialog_generic_with_text(GtkWindow *main_window,
       gtk_window_set_transient_for(GTK_WINDOW(glob_dialog), GTK_WINDOW(main_window));
    }
 
-   frame1 = gtk_frame_new(frame_text);
-   gtk_frame_set_label_align(GTK_FRAME(frame1), 0.5, 0.0);
    vbox1 = gtk_vbox_new(FALSE, 5);
-   hbox1 = gtk_hbox_new(TRUE, 5);
+   gtk_container_add(GTK_CONTAINER(glob_dialog), vbox1);
 
-   gtk_container_set_border_width(GTK_CONTAINER(frame1), 5);
-   gtk_container_set_border_width(GTK_CONTAINER(vbox1), 5);
-   gtk_container_set_border_width(GTK_CONTAINER(hbox1), 5);
-
-   gtk_container_add(GTK_CONTAINER(glob_dialog), frame1);
-   gtk_container_add(GTK_CONTAINER(frame1), vbox1);
-
-
-   if (with_text) {
-#ifndef ENABLE_GTK2
-      text_widget = GTK_TEXT(gtk_text_new(NULL, NULL));
-      gtk_text_set_editable(text_widget, FALSE);
-      gtk_text_set_word_wrap(text_widget, TRUE);
-      gtk_box_pack_start(GTK_BOX(vbox1), GTK_WIDGET(text_widget), TRUE, TRUE, 0);
-      gtk_text_insert(text_widget, NULL, NULL, NULL, text, -1);
-#else
-      text_widget = GTK_TEXT_VIEW(gtk_text_view_new());
-      gtk_text_buffer_set_text(
-	 gtk_text_view_get_buffer(text_widget), text, -1);
-      gtk_text_view_set_editable(text_widget, FALSE);
-      gtk_text_view_set_cursor_visible(text_widget, FALSE);
-      gtk_text_view_set_wrap_mode(text_widget, GTK_WRAP_WORD);
-      gtk_box_pack_start(GTK_BOX(vbox1), GTK_WIDGET(text_widget), TRUE, TRUE, 0);
-#endif
-   } else {
-      label1 = gtk_label_new(text);
-      gtk_box_pack_start(GTK_BOX(vbox1), label1, FALSE, FALSE, 2);
+   hbox1 = gtk_hbox_new(FALSE, 2);
+   gtk_container_add(GTK_CONTAINER(vbox1), hbox1);
+   gtk_container_set_border_width(GTK_CONTAINER(hbox1), 12);
+#ifdef ENABLE_GTK2
+   switch(type)
+   {
+      case DIALOG_INFO:
+	 image = gtk_image_new_from_stock(GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG);
+	 break;
+      case DIALOG_QUESTION:
+	 image = gtk_image_new_from_stock(GTK_STOCK_DIALOG_QUESTION, GTK_ICON_SIZE_DIALOG);
+	 break;
+      case DIALOG_ERROR:
+	 image = gtk_image_new_from_stock(GTK_STOCK_DIALOG_ERROR, GTK_ICON_SIZE_DIALOG);
+	 break;
+      case DIALOG_WARNING:
+	 image = gtk_image_new_from_stock(GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_DIALOG);
+	 break;
+      default:
+	 image = NULL;
    }
+   if (image)
+      gtk_box_pack_start(GTK_BOX(hbox1), image, FALSE, FALSE, 2);
+#endif
+
+   vbox2 = gtk_vbox_new(FALSE, 5);
+   gtk_container_set_border_width(GTK_CONTAINER(vbox2), 5);
+   gtk_box_pack_start(GTK_BOX(hbox1), vbox2, FALSE, FALSE, 2);
+
+   label1 = gtk_label_new(NULL);
+#ifdef ENABLE_GTK2
+   markup = g_markup_printf_escaped("<b><big>%s</big></b>\n\n%s", title, text);
+   gtk_label_set_markup(GTK_LABEL(label1), markup);
+   g_free(markup);
+#else
+   gtk_window_set_title(GTK_WINDOW(glob_dialog), title);
+   gtk_label_set_text(GTK_LABEL(label1), text);
+   gtk_label_set_justify(GTK_LABEL(label1), GTK_JUSTIFY_LEFT);
+#endif
+   gtk_box_pack_start(GTK_BOX(vbox2), label1, FALSE, FALSE, 2);
+
+   hbox1 = gtk_hbutton_box_new();
+   gtk_container_set_border_width(GTK_CONTAINER(hbox1), 12);
+   gtk_button_box_set_layout(GTK_BUTTON_BOX (hbox1), GTK_BUTTONBOX_END);
+   gtk_button_box_set_spacing(GTK_BUTTON_BOX(hbox1), 6);
 
    gtk_box_pack_start(GTK_BOX(vbox1), hbox1, FALSE, FALSE, 2);
 
@@ -1224,10 +1280,13 @@ int dialog_generic_with_text(GtkWindow *main_window,
 			 GTK_SIGNAL_FUNC(cb_dialog_button),
 			 GINT_TO_POINTER(DIALOG_SAID_1 + i));
       gtk_box_pack_start(GTK_BOX(hbox1), button, TRUE, TRUE, 1);
-      if (i == 0)
+
+      /* default button is the last one */
+      if (i == nob-1)
       {
 	 GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
 	 gtk_widget_grab_default(button);
+	 gtk_widget_grab_focus(button);
       }
    }
 
@@ -1238,28 +1297,16 @@ int dialog_generic_with_text(GtkWindow *main_window,
    return dialog_result;
 }
 
-int dialog_generic(GtkWindow *main_window,
-		   int w, int h,
-		   char *title, char *frame_text,
-		   char *text, int nob, char *button_text[])
-{
-   return dialog_generic_with_text(main_window,
-				   w, h,
-				   title, frame_text,
-				   text, nob, button_text,
-				   0);
-}
-
 int dialog_generic_ok(GtkWidget *widget,
-		      char *title, char *frame_text, char *text)
+		      char *title, int type, char *text)
 {
    char *button_text[] = {N_("OK")};
 
    if (widget) {
       return dialog_generic(GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(widget))),
-			    0, 0, title, frame_text, text, 1, button_text);
+			    title, type, text, 1, button_text);
    }
-   return dialog_generic(NULL, 0, 0, title, frame_text, text, 1, button_text);
+   return dialog_generic(NULL, title, type, text, 1, button_text);
 }
 
 
@@ -1271,7 +1318,7 @@ int dialog_generic_ok(GtkWidget *widget,
 int dialog_save_changed_record(GtkWidget *widget, int changed)
 {
    int b;
-   char *button_text[] = {N_("Yes"), N_("No")};
+   char *button_text[] = {N_("No"), N_("Yes")};
 
    b=0;
 
@@ -1279,14 +1326,14 @@ int dialog_save_changed_record(GtkWidget *widget, int changed)
       return EXIT_SUCCESS;
    }
    if (changed==MODIFY_FLAG) {
-      b=dialog_generic(GTK_WINDOW(gtk_widget_get_toplevel(widget)), 0, 0,
-		       _("Save Changed Record?"), NULL,
+      b=dialog_generic(GTK_WINDOW(gtk_widget_get_toplevel(widget)),
+		       _("Save Changed Record?"), DIALOG_QUESTION,
 		       _("Do you want to save the changes to this record?"),
 		       2, button_text);
    }
    if (changed==NEW_FLAG) {
-      b=dialog_generic(GTK_WINDOW(gtk_widget_get_toplevel(widget)), 0, 0,
-		       _("Save New Record?"), NULL,
+      b=dialog_generic(GTK_WINDOW(gtk_widget_get_toplevel(widget)),
+		       _("Save New Record?"), DIALOG_QUESTION,
 		       _("Do you want to save this new record?"),
 		       2, button_text);
    }
@@ -1329,14 +1376,14 @@ int check_hidden_dir()
 {
    struct stat statb;
    char hidden_dir[FILENAME_MAX];
-   char test_file[FILENAME_MAX];
-   FILE *out;
 
    get_home_file_name("", hidden_dir, sizeof(hidden_dir));
    hidden_dir[strlen(hidden_dir)-1]='\0';
 
    if (stat(hidden_dir, &statb)) {
-      /*directory isn't there, create it */
+      /* Directory isn't there, create it. 
+       * Only user is given permission to enter and change directory contents
+       * which provides some primitive privacy protection. */
       if (mkdir(hidden_dir, 0700)) {
 	 /*Can't create directory */
 	 jp_logf(JP_LOG_WARN, _("Can't create directory %s\n"), hidden_dir);
@@ -1354,14 +1401,10 @@ int check_hidden_dir()
       return EXIT_FAILURE;
    }
    /*Can we write in it? */
-   get_home_file_name("test", test_file, sizeof(test_file));
-   out = fopen(test_file, "w+");
-   if (!out) {
+   if (access(hidden_dir, W_OK) != 0) {
       jp_logf(JP_LOG_WARN, _("I can't write files in directory %s\n"), hidden_dir);
-   } else {
-      fclose(out);
-      unlink(test_file);
-   }
+      return EXIT_FAILURE;
+   } 
 
    return EXIT_SUCCESS;
 }
@@ -1454,18 +1497,21 @@ int get_next_unique_pc_id(unsigned int *next_unique_id)
    char file_name[FILENAME_MAX];
    char str[256];
 
-   pc_in_out = jp_open_home_file("next_id", "a+");
+   /* Check that file exists and is non-empty.  If not,
+    * create it and start unique id numbering from 1 */
+   pc_in_out = jp_open_home_file("next_id", "a");
    if (pc_in_out==NULL) {
       jp_logf(JP_LOG_WARN, _("Error opening file: %s\n"),file_name);
       return EXIT_FAILURE;
    }
-
    if (ftell(pc_in_out)==0) {
-      /*We have to write out the file header */
+      /* The file is new.  We have to write out the file header */
       *next_unique_id=1;
       write_to_next_id_open(pc_in_out, *next_unique_id);
    }
    fclose(pc_in_out);
+
+   /* Now that file has been verified we can use it to find the next id */
    pc_in_out = jp_open_home_file("next_id", "r+");
    if (pc_in_out==NULL) {
       jp_logf(JP_LOG_WARN, _("Error opening file: %s\n"),file_name);
@@ -1493,7 +1539,7 @@ int get_next_unique_pc_id(unsigned int *next_unique_id)
 
    write_to_next_id_open(pc_in_out, *next_unique_id);
    fclose(pc_in_out);
-
+   
    return EXIT_SUCCESS;
 }
 
@@ -1511,8 +1557,7 @@ int read_gtkrc_file()
      jp_logf(JP_LOG_DEBUG, "rc file from prefs is NULL\n");
    }
 
-   strncpy(filename, svalue, sizeof(filename));
-   filename[sizeof(filename)-1]='\0';
+   g_strlcpy(filename, svalue, sizeof(filename));
 
    /*Try to read the file out of the home directory first */
    get_home_file_name(filename, fullname, sizeof(fullname));
@@ -1547,6 +1592,10 @@ FILE *jp_open_home_file(char *filename, char *mode)
 	 pc_in = fopen(fullname, mode);
       }
    }
+
+   /* Enhance privacy by only allowing user to read & write files */
+   chmod(fullname, 0600);
+
    return pc_in;
 }
 
@@ -1694,31 +1743,27 @@ unsigned int bytes_to_bin(unsigned char *bytes, unsigned int num_bytes)
    return n;
 }
 
-int raw_header_to_header(RawDBHeader *rdbh, DBHeader *dbh)
+int unpack_db_header(DBHeader *dbh, unsigned char *buffer)
 {
    unsigned long temp;
 
-   strncpy(dbh->db_name, rdbh->db_name, 31);
-   dbh->db_name[sizeof(dbh->db_name)-1] = '\0';
-   dbh->flags = bytes_to_bin(rdbh->flags, 2);
-   dbh->version = bytes_to_bin(rdbh->version, 2);
-   temp = bytes_to_bin(rdbh->creation_time, 4);
+   g_strlcpy(dbh->db_name, buffer, 32);
+   dbh->flags = bytes_to_bin(buffer + 32, 2);
+   dbh->version = bytes_to_bin(buffer + 34, 2);
+   temp = bytes_to_bin(buffer + 36, 4);
    dbh->creation_time = pilot_time_to_unix_time(temp);
-   temp = bytes_to_bin(rdbh->modification_time, 4);
+   temp = bytes_to_bin(buffer + 40, 4);
    dbh->modification_time = pilot_time_to_unix_time(temp);
-   temp = bytes_to_bin(rdbh->backup_time, 4);
+   temp = bytes_to_bin(buffer + 44, 4);
    dbh->backup_time = pilot_time_to_unix_time(temp);
-   dbh->modification_number = bytes_to_bin(rdbh->modification_number, 4);
-   dbh->app_info_offset = bytes_to_bin(rdbh->app_info_offset, 4);
-   dbh->sort_info_offset = bytes_to_bin(rdbh->sort_info_offset, 4);
-   strncpy(dbh->type, rdbh->type, sizeof(dbh->type));
-   dbh->type[sizeof(dbh->type)-1] = '\0';
-   strncpy(dbh->creator_id, rdbh->creator_id, sizeof(dbh->creator_id));
-   dbh->creator_id[sizeof(dbh->creator_id)-1] = '\0';
-   strncpy(dbh->unique_id_seed, rdbh->unique_id_seed, sizeof(dbh->unique_id_seed));
-   dbh->unique_id_seed[sizeof(dbh->unique_id_seed)-1] = '\0';
-   dbh->next_record_list_id = bytes_to_bin(rdbh->next_record_list_id, 4);
-   dbh->number_of_records = bytes_to_bin(rdbh->number_of_records, 2);
+   dbh->modification_number = bytes_to_bin(buffer + 48, 4);
+   dbh->app_info_offset = bytes_to_bin(buffer + 52, 4);
+   dbh->sort_info_offset = bytes_to_bin(buffer + 56, 4);
+   g_strlcpy(dbh->type, buffer + 60, 5);
+   g_strlcpy(dbh->creator_id, buffer + 64, 5);
+   g_strlcpy(dbh->unique_id_seed, buffer + 68, 5);
+   dbh->next_record_list_id = bytes_to_bin(buffer + 72, 4);
+   dbh->number_of_records = bytes_to_bin(buffer + 76, 2);
 
    return EXIT_SUCCESS;
 }
@@ -1782,20 +1827,20 @@ void print_string(char *str, int len)
 /* */
 int get_app_info_size(FILE *in, int *size)
 {
-   RawDBHeader rdbh;
+   unsigned char raw_header[LEN_RAW_DB_HEADER];
    DBHeader dbh;
    unsigned int offset;
    record_header rh;
 
    fseek(in, 0, SEEK_SET);
 
-   fread(&rdbh, sizeof(RawDBHeader), 1, in);
+   fread(raw_header, LEN_RAW_DB_HEADER, 1, in);
    if (feof(in)) {
       jp_logf(JP_LOG_WARN, "get_app_info_size(): %s\n", _("Error reading file"));
       return EXIT_FAILURE;
    }
 
-   raw_header_to_header(&rdbh, &dbh);
+   unpack_db_header(&dbh, raw_header);
 
    if (dbh.app_info_offset==0) {
       *size=0;
@@ -2042,9 +2087,6 @@ int delete_pc_record(AppType app_type, void *VP, int flag)
       fwrite(RecordBuffer->data, header.rec_len, 1, pc_in);
 #endif /* PILOT_LINK_0_12 */
       jp_logf(JP_LOG_DEBUG, "record deleted\n");
-#ifdef PILOT_LINK_0_12
-      pi_buffer_free(RecordBuffer);
-#endif /* PILOT_LINK_0_12 */
       fclose(pc_in);
 #ifdef PILOT_LINK_0_12
       pi_buffer_free(RecordBuffer);
@@ -2457,8 +2499,7 @@ int setup_sync(unsigned int flags)
    jp_logf(JP_LOG_DEBUG, "pref port=[%s]\n", port);
    jp_logf(JP_LOG_DEBUG, "num_backups=%d\n", num_backups);
    get_pref(PREF_USER, NULL, &svalue);
-   strncpy(sync_info.username, svalue, sizeof(sync_info.username));
-   sync_info.username[sizeof(sync_info.username)-1]='\0';
+   g_strlcpy(sync_info.username, svalue, sizeof(sync_info.username));
    get_pref(PREF_USER_ID, &(sync_info.userID), NULL);
 
    get_pref(PREF_PC_ID, &(sync_info.PC_ID), NULL);
@@ -2478,8 +2519,7 @@ int setup_sync(unsigned int flags)
    }
 
    sync_info.sync_over_ride = 0;
-   strncpy(sync_info.port, port, sizeof(sync_info.port));
-   sync_info.port[sizeof(sync_info.port)-1]='\0';
+   g_strlcpy(sync_info.port, port, sizeof(sync_info.port));
    sync_info.flags=flags;
    sync_info.num_backups=num_backups;
 
@@ -2613,8 +2653,7 @@ void charset_p2j(char *const buf, int max_len, int char_set)
 
    newbuf = charset_p2newj(buf, max_len, char_set);
 
-   strncpy(buf, newbuf, max_len);
-   buf[max_len - 1] = '\0';
+   g_strlcpy(buf, newbuf, max_len);
    /* note : string may get truncated within a multibyte char */
    if (strlen(newbuf) >= max_len)
      jp_logf(JP_LOG_WARN, "charset_p2j: buffer too small - string had to be truncated to [%s]\n", buf);
@@ -2632,15 +2671,13 @@ char *charset_p2newj(const char *buf, int max_len, int char_set)
 
    /* allocate a longer buffer if not done in conversion routine */
    if (char_set < CHAR_SET_UTF) {
-      newbuf = (char*)malloc(2*max_len - 1);
+      newbuf = g_malloc(2*max_len - 1);
       if (newbuf) {
 	 /* be safe, though string should fit into buf */
-	 strncpy(newbuf, buf, max_len);
-	 newbuf[max_len - 1] = '\0';
+	 g_strlcpy(newbuf, buf, max_len);
       }
-   } else {
-      newbuf = (char*)NULL; /* keep compiler happy */
    }
+
    switch (char_set) {
     case CHAR_SET_JAPANESE : Sjis2Euc(newbuf, max_len); break;
     case CHAR_SET_1250 : Win2Lat(newbuf,max_len); break;
@@ -3167,3 +3204,57 @@ int get_highlighted_today(struct tm *date)
    /* Today is within the passed month, return the day of month */
    return now_tm->tm_mday;
 }
+
+#ifndef ENABLE_GTK2
+/*	$OpenBSD: strlcpy.c,v 1.8 2003/06/17 21:56:24 millert Exp $	*/
+
+/*
+ * Copyright (c) 1998 Todd C. Miller <Todd.Miller@courtesan.com>
+ *
+ * Permission to use, copy, modify, and distribute this software for any
+ * purpose with or without fee is hereby granted, provided that the above
+ * copyright notice and this permission notice appear in all copies.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
+ * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+ * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
+ * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
+ * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
+ * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ */
+
+#include <sys/types.h>
+#include <string.h>
+
+/*
+ * Copy src to string dst of size siz.  At most siz-1 characters
+ * will be copied.  Always NUL terminates (unless siz == 0).
+ * Returns strlen(src); if retval >= siz, truncation occurred.
+ */
+size_t g_strlcpy(char *dst, const char *src, size_t siz)
+{
+	char *d = dst;
+	const char *s = src;
+	size_t n = siz;
+
+	/* Copy as many bytes as will fit */
+	if (n != 0 && --n != 0) {
+		do {
+			if ((*d++ = *s++) == 0)
+				break;
+		} while (--n != 0);
+	}
+
+	/* Not enough room in dst, add NUL and traverse rest of src */
+	if (n == 0) {
+		if (siz != 0)
+			*d = '\0';		/* NUL-terminate dst */
+		while (*s++)
+			;
+	}
+
+	return(s - src - 1);	/* count does not include NUL */
+}
+#endif
+
