@@ -1,4 +1,7 @@
-/* weekview_gui.c
+/* $Id: weekview_gui.c,v 1.33 2006/06/23 13:38:32 rousseau Exp $ */
+
+/*******************************************************************************
+ * weekview_gui.c
  * A module of J-Pilot http://jpilot.org
  *
  * Copyright (C) 1999-2002 by Judd Montgomery
@@ -15,7 +18,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
+
 #include "config.h"
 #include "i18n.h"
 #include <gtk/gtk.h>
@@ -31,6 +35,7 @@
 
 
 extern int datebook_category;
+extern int glob_app;
 
 
 static GtkWidget *window=NULL;
@@ -52,9 +57,7 @@ static gboolean cb_destroy(GtkWidget *widget)
    return FALSE;
 }
 
-static void
-  cb_quit(GtkWidget *widget,
-	   gpointer   data)
+static void cb_quit(GtkWidget *widget, gpointer data)
 {
    int w, h;
 
@@ -112,9 +115,7 @@ void thaw_weeks_appts()
    }
 }
 
-static void
-cb_week_move(GtkWidget *widget,
-	     gpointer   data)
+static void cb_week_move(GtkWidget *widget, gpointer data)
 {
    if (GPOINTER_TO_INT(data)==-1) {
       sub_days_from_date(&glob_week_date, 7);
@@ -148,7 +149,7 @@ int clear_weeks_appts(GtkWidget **day_texts)
 			      gtk_text_get_length(GTK_TEXT(day_texts[i])));
 #endif
    }
-   return 0;
+   return EXIT_SUCCESS;
 }
 
 /*
@@ -166,13 +167,12 @@ int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts)
    char desc[256];
    char datef[20];
    int n, i;
-   long ivalue;
    const char *svalue;
    char str[82];
    char str_dow[32];
-   long fdow;
    char short_date[32];
    char default_date[]="%x";
+   int now_today;
 #ifdef ENABLE_DATEBK
    int ret;
    int cat_bit;
@@ -181,7 +181,8 @@ int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts)
    struct db4_struct db4;
 #endif
 #ifdef ENABLE_GTK2
-   GObject   *text_buffer;
+   GObject *text_buffer;
+   char    *markup_str;
 #endif
 
    a_list = NULL;
@@ -189,18 +190,37 @@ int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts)
 
    memcpy(&date, date_in, sizeof(struct tm));
 
-   get_pref(PREF_FDOW, &fdow, &svalue);
-
-   get_pref(PREF_SHORTDATE, &ivalue, &svalue);
+   get_pref(PREF_SHORTDATE, NULL, &svalue);
    if (svalue==NULL) {
       svalue = default_date;
    }
 
    for (i=0; i<8; i++, add_days_to_date(&date, 1)) {
       strftime(short_date, sizeof(short_date), svalue, &date);
-      strftime(str_dow, sizeof(str_dow), "%A", &date);
+      jp_strftime(str_dow, sizeof(str_dow), "%A", &date);
+
+      /* Determine today for highlighting */
+      now_today = get_highlighted_today(&date);
+
       g_snprintf(str, sizeof(str), "%s %s", str_dow, short_date);
+
+#ifdef ENABLE_GTK2
+      if (date.tm_mday == now_today)
+      {
+	 markup_str = g_markup_printf_escaped("<b>%s</b>", str);
+      } else {
+	 markup_str = g_markup_printf_escaped("%s", str);
+      }
+      gtk_label_set_markup(GTK_LABEL(glob_dow_labels[i]), markup_str);
+      g_free(markup_str);
+#else
+      if (date.tm_mday == now_today)
+      {
+	 g_snprintf(str, sizeof(str), "%s%s", str, _(" (TODAY)"));
+      }
       gtk_label_set_text(GTK_LABEL(glob_dow_labels[i]), str);
+#endif
+
    }
 
    /* Get all of the appointments */
@@ -215,7 +235,7 @@ int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts)
 #ifdef ENABLE_DATEBK
 	 get_pref(PREF_USE_DB3, &use_db3_tags, NULL);
 	 if (use_db3_tags) {
-	    ret = db3_parse_tag(temp_al->ma.a.note, &db3_type, &db4);
+	    ret = db3_parse_tag(temp_al->mappt.appt.note, &db3_type, &db4);
 	    jp_logf(JP_LOG_DEBUG, "category = 0x%x\n", db4.category);
 	    cat_bit=1<<db4.category;
 	    if (!(cat_bit & datebook_category)) {
@@ -224,19 +244,23 @@ int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts)
 	    }
 	 }
 #endif
-	 if (isApptOnDate(&(temp_al->ma.a), &date)) {
-	    if (temp_al->ma.a.event) {
+	 if (isApptOnDate(&(temp_al->mappt.appt), &date)) {
+	    if (temp_al->mappt.appt.event) {
 	       strcpy(desc, "*");
 	    } else {
 	       get_pref_time_no_secs(datef);
-	       strftime(desc, sizeof(desc), datef, &(temp_al->ma.a.begin));
+	       strftime(desc, sizeof(desc), datef, &(temp_al->mappt.appt.begin));
 	       strcat(desc, " ");
 	    }
-	    if (temp_al->ma.a.description) {
-	       strncat(desc, temp_al->ma.a.description, 70);
+	    if (temp_al->mappt.appt.description) {
+	       strncat(desc, temp_al->mappt.appt.description, 70);
 	       desc[62]='\0';
 	    }
 	    remove_cr_lfs(desc);
+
+	    /* Append number of anniversary years if enabled & appropriate */
+	    append_anni_years(desc, 62, &date, &temp_al->mappt.appt);
+
 	    strcat(desc, "\n");
 #ifdef ENABLE_GTK2
 	    text_buffer = G_OBJECT(gtk_text_view_get_buffer(GTK_TEXT_VIEW(text[n])));
@@ -249,25 +273,49 @@ int display_weeks_appts(struct tm *date_in, GtkWidget **day_texts)
    }
    free_AppointmentList(&a_list);
 
-   return 0;
+   return EXIT_SUCCESS;
+}
+
+/* Called when a day is clicked on the week view */
+static void cb_enter_selected_day(GtkWidget *widget, 
+                                  GdkEvent  *event, 
+				  gpointer   data)
+{
+   struct tm date;
+
+   if (glob_app != DATEBOOK)
+      return;
+
+   date = glob_week_date;
+
+   /* Calculate the date which the user has clicked on */
+   add_days_to_date(&date, GPOINTER_TO_INT(data));
+
+   /* Redisplay the day view based on this date */
+   datebook_gui_setdate(date.tm_year, date.tm_mon, date.tm_mday);
 }
 
 void weekview_gui(struct tm *date_in)
 {
    GtkWidget *button;
+#ifndef ENABLE_GTK2
    GtkWidget *arrow;
+#endif
    GtkWidget *align;
    GtkWidget *vbox, *hbox;
    GtkWidget *hbox_temp;
    GtkWidget *vbox_left, *vbox_right;
-   const char *str_fdow;
    long fdow;
    int i;
    char title[200];
-   unsigned long w, h;
+   long w, h;
 
    if (window) {
-      return;
+       /* Delete any existing window to ensure that new window is biased
+	* around currently selected date and so that the new window
+	* contents are updated with any changes on the day view.
+	*/
+       gtk_widget_destroy(window);
    }
 
    memcpy(&glob_week_date, date_in, sizeof(struct tm));
@@ -295,41 +343,59 @@ void weekview_gui(struct tm *date_in)
    align = gtk_alignment_new(0.5, 0.5, 0, 0);
    gtk_box_pack_start(GTK_BOX(vbox), align, FALSE, FALSE, 0);
 
-   hbox_temp = gtk_hbox_new(FALSE, 0);
+   hbox_temp = gtk_hbutton_box_new();
+   gtk_button_box_set_spacing(GTK_BUTTON_BOX(hbox_temp), 6);
+   gtk_container_set_border_width(GTK_CONTAINER(hbox_temp), 6);
 
    gtk_container_add(GTK_CONTAINER(align), hbox_temp);
 
    /*Make a left arrow for going back a week */
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_GO_BACK);
+#else
    button = gtk_button_new();
    arrow = gtk_arrow_new(GTK_ARROW_LEFT, GTK_SHADOW_OUT);
    gtk_container_add(GTK_CONTAINER(button), arrow);
-   gtk_signal_connect(GTK_OBJECT(button), "clicked", 
+#endif
+   gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_week_move),
 		      GINT_TO_POINTER(-1));
-   gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 3);
+   gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 0);
 
-   /* Create a "Quit" button */
+   /* Create a "Close" button */
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
+#else
    button = gtk_button_new_with_label(_("Close"));
+#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_quit), window);
    gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 0);
 
    /* Create a "Print" button */
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_PRINT);
+#else
    button = gtk_button_new_with_label(_("Print"));
+#endif
    gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_week_print), window);
    gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 0);
 
    /*Make a right arrow for going forward a week */
+#ifdef ENABLE_GTK2
+   button = gtk_button_new_from_stock(GTK_STOCK_GO_FORWARD);
+#else
    button = gtk_button_new();
    arrow = gtk_arrow_new(GTK_ARROW_RIGHT, GTK_SHADOW_OUT);
    gtk_container_add(GTK_CONTAINER(button), arrow);
-   gtk_signal_connect(GTK_OBJECT(button), "clicked", 
+#endif
+   gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_week_move),
 		      GINT_TO_POINTER(1));
-   gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 3);
+   gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 0);
 
-   get_pref(PREF_FDOW, &fdow, &str_fdow);
+   get_pref(PREF_FDOW, &fdow, NULL);
 
    hbox = gtk_hbox_new(FALSE, 0);
    gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 0);
@@ -353,13 +419,16 @@ void weekview_gui(struct tm *date_in)
       gtk_text_view_set_editable(GTK_TEXT_VIEW(glob_week_texts[i]), FALSE);
       gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(glob_week_texts[i]), GTK_WRAP_WORD);
       gtk_container_set_border_width(GTK_CONTAINER(glob_week_texts[i]), 1);
-      gtk_text_buffer_create_tag(GTK_TEXT_BUFFER(glob_week_text_buffers[i]), 
-				 "gray_background", "background", "gray", 
+      gtk_text_buffer_create_tag(GTK_TEXT_BUFFER(glob_week_text_buffers[i]),
+				 "gray_background", "background", "gray",
 			         NULL);
 #else
       glob_week_texts[i] = gtk_text_new(NULL, NULL);
 #endif
       gtk_widget_set_usize(GTK_WIDGET(glob_week_texts[i]), 10, 10);
+      gtk_signal_connect(GTK_OBJECT(glob_week_texts[i]), "button_press_event",
+			 GTK_SIGNAL_FUNC(cb_enter_selected_day),
+			 GINT_TO_POINTER(i));
       if (i>3) {
 	 gtk_box_pack_start(GTK_BOX(vbox_right), glob_dow_labels[i], FALSE, FALSE, 0);
 	 gtk_box_pack_start(GTK_BOX(vbox_right), glob_week_texts[i], TRUE, TRUE, 0);
